@@ -52,16 +52,16 @@ callcase callblocks deffiles makefilename extractcase setlaunch exe start
 _clean_ getblocks getblockelts getrootname definerootcases populatewinners 
 getitem getline getlines getcase getstepsvar tell wash flattenbox enrichbox filterbox givesize 
 $configfile $mypath $exeonfiles $generatechance $file $preventsim $fileconfig $outfile $toshell $report 
-$simnetwork @themereports @simtitles @reporttitles @simdata @retrievedata 
+$simnetwork @themereports %simtitles %reporttitles %retrievedata 
 @keepcolumns @weights @weightsaim @varthemes_report @varthemes_variations @varthemes_steps 
-@rankdata @rankcolumn @reporttempsdata @reportcomfortdata $reportdata 
+@rankdata @rankcolumn @reporttempsdata @reportcomfortdata %reportdata 
 @report_loadsortemps @files_to_filter @filter_reports @base_columns @maketabledata @filter_columns 
 @files_to_filter @filter_reports @base_columns @maketabledata @filter_columns %vals 
 @sweeps @mediumiters @varinumbers @caseseed @chanceseed @chancedata $dimchance $tee @pars_tocheck retrieve
-$target 
+$target %dowhat
 );
 
-$VERSION = '0.44.1'; # our $VERSION = '';
+$VERSION = '0.46.3'; # our $VERSION = '';
 $ABSTRACT = 'Sim::OPT it a tool for detailed metadesign. It manages parametric explorations through the ESP-r building performance simulation platform and performs optimization by block coordinate descent.';
 
 #################################################################################
@@ -926,7 +926,7 @@ sub exe
 		#say $tee "WITH: \@instances " . dump(@instances) . ", \$countcase $countcase, \$countblock $countblock, \%dirfiles " . dump(%dirfiles) . ".";
 		my @result = Sim::OPT::Morph::morph( 
 		{ 
-			instances => \@instances, countcase => $countcase, countblock => $countblock,
+			configfile => $configfile, instances => \@instances, countcase => $countcase, countblock => $countblock,
 			dirfiles => \%dirfiles
 		} );
 		$dirfiles{morphcases} = $result[0];
