@@ -34,9 +34,9 @@ no warnings;
 #%EXPORT_TAGS = ( DEFAULT => [qw( &opt &prepare )]); # our %EXPORT_TAGS = ( 'all' => [ qw( ) ] );
 #@EXPORT   = qw(); # our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
 
-@EXPORT = qw( retrieve report get_files );
+our @EXPORT = qw( retrieve report get_files );
 
-$VERSION = '0.43.0'; # our $VERSION = '';
+$VERSION = '0.46.0'; # our $VERSION = '';
 
 
 #########################################################################################
@@ -49,23 +49,23 @@ sub retrieve
 	my $swap = shift; #say TOSHELL "swapINRETRIEVE: " . dump($swap);
 	my %dat = %$swap;
 	my @instances = @{ $dat{instances} }; #say "scalar(\@instances): " . scalar(@instances);
-	my $countcase = $dat{countcase}; say TOSHELL "dump(\$countcase): " . dump($countcase); # IT WILL BE SHADOWED. CUT ZZZ
-	my $countblock = $dat{countblock}; say TOSHELL "dump(\$countblock): " . dump($countblock); # IT WILL BE SHADOWED. CUT ZZZ		
+	my $countcase = $dat{countcase}; #say TOSHELL "dump(\$countcase): " . dump($countcase); # IT WILL BE SHADOWED. CUT ZZZ
+	my $countblock = $dat{countblock}; #say TOSHELL "dump(\$countblock): " . dump($countblock); # IT WILL BE SHADOWED. CUT ZZZ		
 	my %dirfiles = %{ $dat{dirfiles} }; #say "dump(\%dirfiles): " . dump(%dirfiles); 
 		
 	$configfile = $main::configfile; #say "dump(\$configfile): " . dump($configfile);
-	@sweeps = @main::sweeps; say TOSHELL "dump(\@sweeps): " . dump(@sweeps);
+	@sweeps = @main::sweeps; #say TOSHELL "dump(\@sweeps): " . dump(@sweeps);
 	@varinumbers = @main::varinumbers; #say "dump(\@varinumbers): " . dump(@varinumbers);
 	@mediumiters = @main::mediumiters;
 	@rootnames = @main::rootnames; #say "dump(\@rootnames): " . dump(@rootnames);
 	%vals = %main::vals; #say "dump(\%vals): " . dump(%vals);
 	
 	$mypath = $main::mypath;  #say TOSHELL "dumpINRETRIEVE(\$mypath): " . dump($mypath);
-	$exeonfiles = $main::exeonfiles; say TOSHELL "dumpINRETRIEVE(\$exeonfiles): " . dump($exeonfiles);
+	$exeonfiles = $main::exeonfiles; #say TOSHELL "dumpINRETRIEVE(\$exeonfiles): " . dump($exeonfiles);
 	$generatechance = $main::generatechance; 
 	$file = $main::file;
 	$preventsim = $main::preventsim;
-	$fileconfig = $main::fileconfig; say TOSHELL "dumpINRETRIEVE(\$fileconfig): " . dump($fileconfig); # NOW GLOBAL. TO MAKE IT PRIVATE, FIX PASSING OF PARAMETERS IN CONTRAINTS PROPAGATION SECONDARY SUBROUTINES
+	$fileconfig = $main::fileconfig; #say TOSHELL "dumpINRETRIEVE(\$fileconfig): " . dump($fileconfig); # NOW GLOBAL. TO MAKE IT PRIVATE, FIX PASSING OF PARAMETERS IN CONTRAINTS PROPAGATION SECONDARY SUBROUTINES
 	$outfile = $main::outfile;
 	$toshell = $main::toshell;
 	$report = $main::report;
@@ -76,13 +76,12 @@ sub retrieve
 	open( OUTFILE, ">>$outfile" ) or die "Can't open $outfile: $!"; 
 	open( TOSHELL, ">>$toshell" ) or die "Can't open $toshell: $!"; 
 	say "\nNow in Sim::OPT::Report::retrieve.\n";
-	say TOSHELL "\n#Now in Sim::OPT::Report_retrieve.\n";
+	say $tee "\n#Now in Sim::OPT::Report_retrieve.\n";
 	
 	%dowhat = %main::dowhat;
 
-	@simtitles = @main::simtitles; say TOSHELL "dumpINRETRIEVE(\@simtitles): " . dump(@simtitles);
-	@simdata = @main::simdata;
-	@retrievedata = @main::retrievedata;
+	%simtitles = %main::simtitles; #say $tee "dumpINRETRIEVE(\%simtitles): " . dump(%simtitles);
+	%retrievedata = %main::retrievedata;
 	@keepcolumns = @main::keepcolumns;
 	@weights = @main::weights;
 	@weightsaim = @main::weightsaim;
@@ -91,7 +90,7 @@ sub retrieve
 	@varthemes_steps = @main::varthemes_steps;
 	@rankdata = @main::rankdata; # CUT ZZZ
 	@rankcolumn = @main::rankcolumn;
-	$reportdata = $main::reportdata; say TOSHELL "dump(\$reportdata): " . dump($reportdata);
+	%reportdata = %main::reportdata; #say $tee "dump(\%reportdata): " . dump(%reportdata);
 	@files_to_filter = @main::files_to_filter;
 	@filter_reports = @main::filter_reports;
 	@base_columns = @main::base_columns;
@@ -99,8 +98,8 @@ sub retrieve
 	@filter_columns = @main::filter_columns;
 	%vals = %main::vals;
 	
-	my @simcases = @{ $dirfiles{simcases} }; say TOSHELL "dump(\@simcases): " . dump(@simcases);
-	my @simstruct = @{ $dirfiles{simstruct} }; say TOSHELL "dump(\@simstruct): " . dump(@simstruct);
+	my @simcases = @{ $dirfiles{simcases} }; #say $tee "dump(\@simcases): " . dump(@simcases);
+	my @simstruct = @{ $dirfiles{simstruct} }; #say $tee "dump(\@simstruct): " . dump(@simstruct);
 	my @morphcases = @{ $dirfiles{morphcases} };
 	my @morphstruct = @{ $dirfiles{morphstruct} };
 	my @retcases = @{ $dirfiles{retcases} };
@@ -112,9 +111,9 @@ sub retrieve
 	my @descendcases = @{ $dirfiles{descendcases} };
 	my @descendstruct = @{ $dirfiles{descendstruct} };
 	
-	my $morphlist = $dirfiles{morphlist}; say TOSHELL "dump(\$morphlist): " . dump($morphlist);
+	my $morphlist = $dirfiles{morphlist}; #say $tee "dump(\$morphlist): " . dump($morphlist);
 	my $morphblock = $dirfiles{morphblock};
-	my $simlist = $dirfiles{simlist}; say TOSHELL "dump(\$simlist): " . dump($simlist);
+	my $simlist = $dirfiles{simlist}; #say $tee "dump(\$simlist): " . dump($simlist);
 	my $simblock = $dirfiles{simblock};
 	my $retlist = $dirfiles{retlist};
 	my $retblock = $dirfiles{retblock};
@@ -123,9 +122,9 @@ sub retrieve
 	my $descendlist = $dirfiles{descendlist};
 	my $descendblock = $dirfiles{descendblock};
 	
-	my $skipfile = $vals{skipfile}; say TOSHELL "dump(\$skipfile): " . dump($skipfile);
-	my $skipsim = $vals{skipsim}; say TOSHELL "dump(\$skipsim): " . dump($skipsim);
-	my $skipreport = $vals{skipreport}; say TOSHELL "dump(\$skipreport): " . dump($skipreport);	
+	my $skipfile = $vals{skipfile}; #say $tee "dump(\$skipfile): " . dump($skipfile);
+	my $skipsim = $vals{skipsim}; #say $tee "dump(\$skipsim): " . dump($skipsim);
+	my $skipreport = $vals{skipreport}; #say $tee "dump(\$skipreport): " . dump($skipreport);	
 	my %notecases;
 	
 	#my $getpars = shift;
@@ -140,47 +139,57 @@ sub retrieve
 		my %d = %{$instance};
 		my $countcase = $d{countcase}; #say TOSHELL "dump(\$countcase): " . dump($countcase);
 		my $countblock = $d{countblock}; #say TOSHELL "dump(\$countblock): " . dump($countblock);
-		my @miditers = @{ $d{miditers} }; say TOSHELL "dump(\@miditers): " . dump(@miditers);
+		my @miditers = @{ $d{miditers} }; #say $tee "dump(\@miditers): " . dump(@miditers);
 		my @winneritems = @{ $d{winneritems} }; #say TOSHELL "dumpIN( \@winneritems) " . dump(@winneritems);
 		my $countvar = $d{countvar}; #say TOSHELL "dump(\$countvar): " . dump($countvar);
 		my $countstep = $d{countstep}; #say TOSHELL "dump(\$countstep): " . dump($countstep);						
-		my $to = $d{to}; say TOSHELL "dump(\$to): " . dump($to);
+		my $to = $d{to}; #say TOSHELL "dump(\$to): " . dump($to);
 		my $origin = $d{origin}; #say TOSHELL "dump(\$origin): " . dump($origin);
 		my @uplift = @{ $d{uplift} }; #say TOSHELL "dump(\@uplift): " . dump(@uplift);
 		#eval($getparshere);
 		
-		my $skip = $vals{$countvar}{skip}; say TOSHELL "dumpinreport(\$skip): " . dump($skip);
+		my $skip = $vals{$countvar}{skip}; #say $tee "dumpinreport(\$skip): " . dump($skip);
 		
 		my $rootname = Sim::OPT::getrootname(\@rootnames, $countcase); #say TOSHELL "dump(\$rootname): " . dump($rootname);
 		my @blockelts = Sim::OPT::getblockelts(\@sweeps, $countcase, $countblock); #say TOSHELL "dumpIN( \@blockelts) " . dump(@blockelts);
 		my @blocks = Sim::OPT::getblocks(\@sweeps, $countcase);  #say TOSHELL "dumpIN( \@blocks) " . dump(@blocks);
 		my $toitem = Sim::OPT::getitem(\@winneritems, $countcase, $countblock); #say TOSHELL "dump(\$toitem): " . dump($toitem);
-		my $from = Sim::OPT::getline($toitem); say TOSHELL "dumpIN(\$from): " . dump($from);
+		my $from = Sim::OPT::getline($toitem); #say $tee "dumpIN(\$from): " . dump($from);
 		my %varnums = Sim::OPT::getcase(\@varinumbers, $countcase); #say TOSHELL "dumpIN---(\%varnums): " . dump(%varnums); 
 		my %mids = Sim::OPT::getcase(\@miditers, $countcase); #say TOSHELL "dumpIN---(\%mids): " . dump(%mids); 
 		#eval($getfly);
 		
 		my $stepsvar = Sim::OPT::getstepsvar($countvar, $countcase, \@varinumbers); #say TOSHELL "dump(\$stepsvar): " . dump($stepsvar); 
 		my $varnumber = $countvar; #say TOSHELL "dump---(\$varnumber): " . dump($varnumber) . "\n\n";  # LEGACY VARIABLE
-
-		sub retrieve_temperatures_results 
-		{
-			my ( $result, $resfile, $swap, $reporttitle, $theme, $counttheme, $countreport, $retfile ) = @_;
-			my @retrdata = @$swap;
-			
-			say "INRETRIEVE0\$countcase : " . dump($countcase);
-			say "INRETRIEVE1\@rootnames : " . dump(@rootnames);
-			say "INRETRIEVE1\$countblock : " . dump($countblock);
-			say "INRETRIEVE1\@sweeps : " . dump(@sweeps);
-			say "INRETRIEVE1\@varinumbers : " . dump(@varinumbers);
-			say "INRETRIEVE1\@miditers : " . dump(@miditers);
-			say "INRETRIEVE1\@winneritems : " . dump(@winneritems);
-			say "INRETRIEVE1\@morphcases : " . dump(@morphcases);
-			say "INRETRIEVE1\@morphstruct : " . dump(@morphstruct);
-
-			unless (-e "$retfile-")
+		
+		my $numberof_simtools = scalar ( keys %{ $dowhat{simtools} } ); #say $tee "\$numberof_simtools " . dump( $numberof_simtools );
+		
+		my $counttool = 1;
+		while ( $counttool <= $numberof_simtools )
+		{	
+			my $skip = $vals{$countvar}{$counttool}{skip}; #say $tee "dumpinsim(\$skip): " . dump($skip);
+			if ( not ( eval ( $skipsim{$counttool} )))
 			{
-				my $printthis = 
+				my $tooltype = $dowhat{simtools}{$counttool}; #say $tee "\$tooltype " . dump( $tooltype );
+
+				sub retrieve_temperatures_results 
+				{
+					my ( $result, $resfile, $retrdata_ref, $reporttitle, $themereport, $counttheme, $countreport, $retfile ) = @_;
+					my @retrdata = @$retrdata_ref;
+					
+					say "INRETRIEVE0\$countcase : " . dump($countcase);
+					say "INRETRIEVE1\@rootnames : " . dump(@rootnames);
+					say "INRETRIEVE1\$countblock : " . dump($countblock);
+					say "INRETRIEVE1\@sweeps : " . dump(@sweeps);
+					say "INRETRIEVE1\@varinumbers : " . dump(@varinumbers);
+					say "INRETRIEVE1\@miditers : " . dump(@miditers);
+					say "INRETRIEVE1\@winneritems : " . dump(@winneritems);
+					say "INRETRIEVE1\@morphcases : " . dump(@morphcases);
+					say "INRETRIEVE1\@morphstruct : " . dump(@morphstruct);
+
+					unless (-e "$retfile-")
+					{
+						my $printthis = 
 "res -file $resfile -mode script<<YYY
 
 3
@@ -211,28 +220,28 @@ $retfile
 -
 YYY
 ";
-				if ($exeonfiles eq "y")
-				{ 	
-					say "Retrieving temperature results.";
-					say TOSHELL "#Retrieving temperature results.";
-					print `$printthis`;
+						if ($exeonfiles eq "y")
+						{ 	
+							say "Retrieving temperature results.";
+							say $tee "#Retrieving temperature results.";
+							print `$printthis`;
+						}
+						print $tee "
+			#Retrieving results for case " . ($countcase + 1) . ", block " . ($countblock + 1) . ", simulation period $counttheme, retrieve period $countreport\n
+			$printthis";
+
+					}
 				}
-				print TOSHELL "
-	#Retrieving results for case " . ($countcase + 1) . ", block " . ($countblock + 1) . ", simulation period $counttheme, retrieve period $countreport\n
-	$printthis";
 
-			}
-		}
+				sub retrieve_comfort_results
+				{
+					my ( $result, $resfile, $retrdata_ref, $reporttitle, $stripcheck, $themereport, $counttheme, $countreport, $retfile ) = @_;
+					
+					my @retrdata = @$retrdata_ref;
 
-		sub retrieve_comfort_results
-		{
-			my ( $result, $resfile, $swap, $reporttitle, $stripcheck, $theme, $counttheme, $countreport, $retfile ) = @_;
-			
-			my @retrdata = @$swap;
-
-			unless (-e "$retfile-")
-			{
-				my $printthis =
+					unless (-e "$retfile-")
+					{
+						my $printthis =
 "res -file $resfile -mode script<<ZZZ
 
 3
@@ -262,29 +271,29 @@ $retfile
 -
 ZZZ
 ";
-				if ($exeonfiles eq "y") 
-				{ 
-					say "Retrieving comfort results.";
-					say TOSHELL "#Retrieving comfort results.";
-					print `$printthis`;
+						if ($exeonfiles eq "y") 
+						{ 
+							say "Retrieving comfort results.";
+							say TOSHELL "#Retrieving comfort results.";
+							print `$printthis`;
+						}
+						print TOSHELL "
+		#Retrieving results for case " . ($countcase + 1) . ", block " . ($countblock + 1) . ", simulation period $counttheme, retrieve period $countreport\n
+		$printthis";
+					}
 				}
-				print TOSHELL "
-#Retrieving results for case " . ($countcase + 1) . ", block " . ($countblock + 1) . ", simulation period $counttheme, retrieve period $countreport\n
-$printthis";
-			}
-		}
 
-		sub retrieve_stats_results
-		{	
-			my ( $result, $resfile, $retrdata_ref, $reporttitle, $theme, $counttheme, $countreport, $retfile, $semaphorego, $semaphorestop, $textpattern) = @_;
-			print TOSHELL " IN RETRIEVE STATS: \$sim: $sim, \$resfile: $resfile, \$result: $result, \$reporttitle: $reporttitle, \$theme: $theme, \$counttheme: $counttheme, \$countreport, $countreport, \$retfile : $retfile \n";
-			print TOSHELL "\@retrievedata: " . dump( @retrievedata ); 
-			my @retrdata = @$retrdata_ref; say TOSHELL "\@retrdata " . dump(@retrdata);
-			my $printthis;
-			
-			if ( $theme eq "loads" )
-			{
-				$printthis =
+				sub retrieve_stats_results
+				{	
+					my ( $result, $resfile, $retrdata_ref, $reporttitle, $themereport, $counttheme, $countreport, $retfile, $semaphorego, $semaphorestop, $textpattern) = @_;
+					print $tee " IN RETRIEVE STATS: \$sim: $sim, \$resfile: $resfile, \$result: $result, \$reporttitle: $reporttitle, \$themereport: $themereport, \$counttheme: $counttheme, \$countreport, $countreport, \$retfile : $retfile \n";
+					print $tee "\%retrievedata: " . dump( %retrievedata ); 
+					my @retrdata = @$retrdata_ref; say $tee "\@retrdata " . dump(@retrdata);
+					my $printthis;
+					
+					if ( $themereport eq "loads" )
+					{
+						$printthis =
 "res -file $resfile -mode script<<TTT
 
 3
@@ -304,12 +313,12 @@ a
 -
 -
 TTT
-	";
-	
-			}
-			elsif ( $theme eq "tempsstats" )
-			{
-				$printthis =
+";
+			
+					}
+					elsif ( $themereport eq "tempsstats" )
+					{
+						$printthis =
 "res -file $resfile -mode script<<TTT
 
 3
@@ -328,138 +337,148 @@ m
 -
 TTT
 ";
-			}
-			if ($exeonfiles eq "y") 
-			{
-				say "Retrieving $theme results.";
-				say TOSHELL "#Retrieving $theme results.";
-				print `$printthis`;
-			}
-			print TOSHELL " 
-#Retrieving results for case " . ($countcase + 1) . ", block " . ($countblock + 1) . ", simulation period $counttheme, retrieve period $countreport\n
-$printthis
-";
-
-		}
-		
-		#say TOSHELL "\nNow in Sim::OPT::Retrieve. INSIDE";
-		my @resfiles = @{ $simstruct[$countcase][$countblock][$countinstance] }; say TOSHELL "SAY\@resfiles " . dump(@resfiles); 
-		#say TOSHELL "SAY\@simcases " . dump(@simcases); say TOSHELL "SAY\@simstruct " . dump(@simstruct); 
-		
-		
-		say TOSHELL "\@retrievedata " . dump(@retrievedata);
-		my $counttheme = 0;
-		foreach my $retrievedatum (@retrievedata)
-		{	say TOSHELL "\$retrievedatum " . dump($retrievedatum);
-			my $reportdata_ref_ref = $reportdata->[$counttheme]; say TOSHELL "\$reportdata_ref_ref " . dump($reportdata_ref_ref);
-			my $retrievedatarefsdeep = $retrievedata[$counttheme]; say TOSHELL "\$retrievedatarefsdeep " . dump($retrievedatarefsdeep);
-			my @retrievedatarefs = @{$retrievedatum}; say TOSHELL "\@retrievedatarefs " . dump(@retrievedatarefs);
-			my $simtitle = $simtitles[$counttheme]; say TOSHELL "\$simtitle " . dump($simtitle);
-			my @sims = @{ $simdata[ $countheme ] }; say TOSHELL "\@sims " . dump(@sims);
-			
-			my $resfile = $resfiles[ $counttheme ]; say TOSHELL "\HERE\$resfile " . dump($resfile);
-			
-			#if ( not ( eval ( $skipreport ) ) )
-			if ( -e $resfile ) 
-			{
-				
-				my $countreport = 0;
-				foreach my $retrievedataref (@retrievedatarefs)
-				{
-					say TOSHELL "\$retrievedataref " . dump($retrievedataref);
-					my @retrdata = @$retrievedataref; say TOSHELL "\@retrdata " . dump(@retrdata);
-					my $sim = $sims[$countreport]; say TOSHELL "\$sim-RESFILE" . dump($sim); 
-					my $targetprov = $sim;
-					$targetprov =~ s/$mypath\///;
-					my $result = "$mypath" . "/$targetprov"; say TOSHELL "\$result " . dump($result); 
-					
-					#if ( fileno (RETLIST) )
-					#if (not (-e $retlist ) )
-					#{
-					#	if ( $countblock == 0 )
-					#	{
-							open( RETLIST, ">>$retlist"); # or die;
-					#	}
-					#	else 
-					#	{
-					#		open( RETLIST, ">>$retlist"); # or die;
-					#	}
-					#}
-					
-					#if ( fileno (RETLIST) ) # SAME LEVEL OF RETLIST. JUST ANOTHER CONTAINER.
-					#if (not (-e $retblock ) )
-					#{
-					#	if ( $countblock == 0 )
-					#	{
-							open( RETBLOCK, ">>$retblock"); # or die;
-					#	}
-					#	else 
-					#	{
-					#		open( RETBLOCK, ">>$retblock"); # or die;
-					#	}
-					#}
-									
-					my $reportdata_ref = $reportdata_ref_ref->[$countreport]; say TOSHELL "\$reportdata_ref" . dump($reportdata_ref); 
-					my @reportdata = @$reportdata_ref;  say TOSHELL "\@reportdata" . dump(@reportdata); 
-					
-					my $countitem = 0;
-					foreach my $item ( @reportdata )
-					{
-						my %datarep = %$item; say TOSHELL "\%datarep" . dump(%datarep); 
-						my $reporttitle = $datarep{reporttitle}; say TOSHELL "\$reporttitle! " . dump($reporttitle); ###DDD HERE
-						my $theme = $datarep{themereport}; say TOSHELL "\$theme " . dump($theme); 
-						my $semaphorego = $datarep{semaphorego}; say TOSHELL "\$semaphorego " . dump($semaphorego); 
-						my $semaphorestop = $datarep{semaphorestop}; say TOSHELL "\$semaphorestop " . dump($semaphorestop); 
-						my $textpattern = $datarep{textpattern}; say TOSHELL "\$textpattern " . dump($textpattern); 
-						
-						my $retfile = "$resfile-$reporttitle-$theme.grt"; say TOSHELL "\$retfile " . dump($retfile); 
-								
-						say TOSHELL "\$retfile " . dump($retfile);
-						
-						$retstruct[$countcase][$countblock][ $countinstance ][$counttheme][$countreport][$countitem] = $retfile;
-						print RETBLOCK "$retfile\n";
-						
-						if ( not ($retfile ~~ @retcases ) )
-						{
-							push ( @retcases, $retfile );
-							say RETLIST "$retfile";
-						}
-						
-						if ( not ($retfile ~~ @{ $notecases[ $countcase ][ $countblock ][ $countinstance ] } ) )
-						{
-							$notecases[ $countcase ][ $countblock ][ $countinstance ][ $countitem ] = 
-																{
-																	retfile => $retfile,
-																	reporttitle => $reporttitle,
-																	themereport => $themereport,
-																	semaphorego => $semaphorego,
-																	semaphorestop => $semaphorestop,
-																	textpattern => $textpattern
-																};
-						}
-						
-						say "#Retrieving results for case " . ($countcase + 1) . ", block " . ($countblock + 1) . ", parameter $countvar at iteration $countstep. Instance $countinstance: going to write $retfile.\ ";
-							
-						if ( $theme eq "temps" ) 
-						{
-							 retrieve_temperatures_results( $result, $resfile, \@retrdata, $reporttitle, $theme, $counttheme, $countreport, $retfile ); 
-						}
-						elsif ( $theme eq "comfort"  ) 
-						{ 
-							retrieve_comfort_results( $result, $resfile, \@retrdata, $reporttitle, $theme, $counttheme, $countreport, $retfile ); 
-						}
-						elsif ( ( $theme eq "loads" ) or ( $theme eq "tempsstats"  ) )
-						{ 
-							retrieve_stats_results( $result, $resfile, \@retrdata, $reporttitle, $theme, $counttheme, 
-										$countreport, $retfile, $semaphorego, $semaphorestop, $textpattern ); 
-						}
-						$countitem++;
 					}
-					$countreport++;
+					if ($exeonfiles eq "y") 
+					{
+						#say "Retrieving $themereport results.";
+						say $tee "#Retrieving $themereport results.";
+						print `$printthis`;
+					}
+					print $tee " 
+		#Retrieving results for case " . ($countcase + 1) . ", block " . ($countblock + 1) . ", simulation period $counttheme, retrieve period $countreport\n
+		$printthis
+		";
+
 				}
-			
+				
+				say $tee "\nNow in Sim::OPT::Retrieve. INSIDE";
+				my @resfiles = @{ $simstruct[$countcase][$countblock][$countinstance][$counttool] }; say $tee "SAY\@resfiles " . dump(@resfiles); 
+				#say $tee "SAY\@simcases " . dump( @simcases ); say $tee "SAY\@simstruct " . dump(@simstruct); 
+				
+				#say $tee "\%retrievedata " . dump( %retrievedata );
+				#say $tee "\$retrievedata{\$counttool} " . dump( $retrievedata{$counttool} );
+				
+				if ( $retrievedata{$counttool} )
+				{
+					if ( $tooltype eq "esp-r" )
+					{
+						my $counttheme = 0;
+						foreach my $retrievedatum ( @{ $retrievedata{$counttool} } )
+						{	
+							#say $tee "\$retrievedatum " . dump($retrievedatum);
+							my $reportdata_ref_ref = $reportdata{$counttool}->[$counttheme]; #say $tee "\$reportdata_ref_ref " . dump($reportdata_ref_ref);
+							my $retrievedatarefsdeep = $retrievedata{$counttool}[$counttheme]; #say $tee "\$retrievedatarefsdeep " . dump($retrievedatarefsdeep);
+							my @retrievedatarefs = @{$retrievedatum}; #say $tee "\@retrievedatarefs " . dump(@retrievedatarefs);
+							my $simtitle = $simtitles{$counttool}->[ $counttheme ][0]; #say $tee "\$simtitle " . dump($simtitle);
+							my @sims = @{ $simtitles{$counttool}->[ $counttheme ] }[1..4]; #say $tee "\@sims " . dump(@sims);
+							
+							my $resfile = $resfiles[ $counttheme ]; #say $tee "\HERE\$resfile " . dump($resfile);
+							
+							#if ( not ( eval ( $skipreport ) ) )
+							if ( -e $resfile ) 
+							{
+								
+								my $countreport = 0;
+								foreach my $retrievedataref (@retrievedatarefs)
+								{
+									#say $tee "\$retrievedataref " . dump($retrievedataref);
+									my @retrdata = @$retrievedataref; #say $tee "\@retrdata " . dump(@retrdata);
+									my $sim = $sims[$countreport]; #say $tee "\$sim-RESFILE" . dump($sim); 
+									my $targetprov = $sim;
+									$targetprov =~ s/$mypath\///;
+									my $result = "$mypath" . "/$targetprov"; #say $tee "\$result " . dump($result); 
+									
+									#if ( fileno (RETLIST) )
+									#if (not (-e $retlist ) )
+									#{
+									#	if ( $countblock == 0 )
+									#	{
+											open( RETLIST, ">>$retlist"); # or die;
+									#	}
+									#	else 
+									#	{
+									#		open( RETLIST, ">>$retlist"); # or die;
+									#	}
+									#}
+									
+									#if ( fileno (RETLIST) ) # SAME LEVEL OF RETLIST. JUST ANOTHER CONTAINER.
+									#if (not (-e $retblock ) )
+									#{
+									#	if ( $countblock == 0 )
+									#	{
+											open( RETBLOCK, ">>$retblock"); # or die;
+									#	}
+									#	else 
+									#	{
+									#		open( RETBLOCK, ">>$retblock"); # or die;
+									#	}
+									#}
+													
+									my $reportdata_ref = $reportdata_ref_ref->[$countreport]; say $tee "\$reportdata_ref" . dump($reportdata_ref); 
+									my @reportdata = @$reportdata_ref;  say $tee "\@reportdata" . dump(@reportdata); 
+									
+									my $countitem = 0;
+									foreach my $item ( @reportdata )
+									{
+										my %datarep = %$item; say $tee "\%datarep" . dump(%datarep); 
+										my $reporttitle = $datarep{reporttitle}; say $tee "\$reporttitle! " . dump($reporttitle); ###DDD HERE
+										my $themereport = $datarep{themereport}; say $tee "\$themereport " . dump($themereport); 
+										my $semaphorego = $datarep{semaphorego}; say $tee "\$semaphorego " . dump($semaphorego); 
+										my $semaphorestop = $datarep{semaphorestop}; say $tee "\$semaphorestop " . dump($semaphorestop); 
+										my $textpattern = $datarep{textpattern}; say $tee "\$textpattern " . dump($textpattern); 
+										my $retfile = "$resfile-$reporttitle-$themereport.grt"; #say $tee "\$retfile " . dump($retfile); say TOSHELL "\$retfile " . dump($retfile); say TOSHELL "\$retfile " . dump($retfile);
+										
+										$retstruct[$countcase][$countblock][ $countinstance ][$counttheme][$countreport][$countitem][$counttool] = $retfile;
+										print RETBLOCK "$retfile\n";
+										
+										if ( not ($retfile ~~ @retcases ) )
+										{
+											push ( @retcases, $retfile );
+											say RETLIST "$retfile";
+										}
+										
+										if ( not ( $retfile ~~ @{ $notecases[ $countcase ][ $countblock ][ $countinstance ][ $counttool ] } ) )
+										{
+											
+											push ( @{ $notecases[ $countcase ][ $countblock ][ $countinstance ][ $counttool ] } , 
+																				{
+																					retfile => $retfile,
+																					reporttitle => $reporttitle,
+																					themereport => $themereport,
+																					semaphorego => $semaphorego,
+																					semaphorestop => $semaphorestop,
+																					textpattern => $textpattern
+																				} );
+										}
+										
+										say "#Retrieving results for case " . ($countcase + 1) . ", block " . ($countblock + 1) . ", parameter $countvar at iteration $countstep for tool $tooltype. Instance $countinstance: going to write $retfile.\ ";
+											
+										if ( $themereport eq "temps" ) 
+										{
+											 retrieve_temperatures_results( $result, $resfile, \@retrdata, $reporttitle, $themereport, $counttheme, $countreport, $retfile ); 
+										}
+										elsif ( $themereport eq "comfort"  ) 
+										{ 
+											retrieve_comfort_results( $result, $resfile, \@retrdata, $reporttitle, $themereport, $counttheme, $countreport, $retfile ); 
+										}
+										elsif ( ( ( $themereport eq "loads" ) or ( $themereport eq "tempsstats"  ) ) )
+										{ 
+											retrieve_stats_results( $result, $resfile, \@retrdata, $reporttitle, $themereport, $counttheme, 
+														$countreport, $retfile, $semaphorego, $semaphorestop, $textpattern ); 
+										}
+										$countitem++;
+									}
+									$countreport++;
+								}
+							}
+							$counttheme++;
+						}
+					}
+				}
+				
+					
 			}
-			$counttheme++;
+			$counttool++;
 		}
 		$countinstance++;
 	}
@@ -469,7 +488,8 @@ $printthis
 	close TOSHELL;
 	close RETLIST;
 	close RETBLOCK;
-	return ( \@retcases, \@retstruct, \%notecases );
+	say $tee "\@notecases " . dump( @notecases ); 
+	return ( \@retcases, \@retstruct, \@notecases );
 }	# END SUB RETRIEVE
 
 
@@ -509,9 +529,8 @@ sub report # This function retrieves the results of interest from the texts file
 	
 	%dowhat = %main::dowhat;
 
-	@simtitles = @main::simtitles; #say TOSHELL "dumpINDESCEND(\@simtitles): " . dump(@simtitles);
-	@simdata = @main::simdata;
-	@retrievedata = @main::retrievedata;
+	%simtitles = %main::simtitles; say $tee "dumpINRETRIEVE(\%simtitles): " . dump(%simtitles);
+	%retrievedata = %main::retrievedata;
 	@keepcolumns = @main::keepcolumns;
 	@weights = @main::weights;
 	@weightsaim = @main::weightsaim;
@@ -520,12 +539,13 @@ sub report # This function retrieves the results of interest from the texts file
 	@varthemes_steps = @main::varthemes_steps;
 	@rankdata = @main::rankdata; # CUT ZZZ
 	@rankcolumn = @main::rankcolumn;
-	$reportdata = $main::reportdata;
+	%reportdata = %main::reportdata; say $tee "dump(\%reportdata): " . dump(%reportdata);
 	@files_to_filter = @main::files_to_filter;
 	@filter_reports = @main::filter_reports;
 	@base_columns = @main::base_columns;
 	@maketabledata = @main::maketabledata;
 	@filter_columns = @main::filter_columns;
+	%notecases = %main::notecases;
 	
 	my @simcases = @{ $dirfiles{simcases} }; #say "dump(\@simcases): " . dump(@simcases);
 	my @simstruct = @{ $dirfiles{simstruct} }; #say "dump(\@simstruct): " . dump(@simstruct);
@@ -539,7 +559,7 @@ sub report # This function retrieves the results of interest from the texts file
 	my @mergestruct = @{ $dirfiles{mergestruct} };
 	my @descendcases = @{ $dirfiles{descendcases} };
 	my @descendstruct = @{ $dirfiles{descendstruct} };
-	my %notecases = %{ $dirfiles{notecases} }; say TOSHELL "dump(\%notecases): " . dump(%notecases);
+	my @notecases = @{ $dirfiles{notecases} }; say TOSHELL "dump(\@notecases): " . dump(@notecases);
 	
 	my $morphlist = $dirfiles{morphlist}; #say "dump(\$dat{morphlist}): " . dump($dat{morphlist});
 	my $morphblock = $dirfiles{morphblock};
@@ -583,8 +603,6 @@ sub report # This function retrieves the results of interest from the texts file
 		my $varnumber = $countvar; #say TOSHELL "dump---(\$varnumber): " . dump($varnumber) . "\n\n";  # LEGACY VARIABLE
 
 		say TOSHELL "#Processing reports for case " . ($countcase + 1) . ", block " . ($countblock + 1);
-		#say "THEMEREPORTS::report: " . dump (@themereports);
-		#say TOSHELL "THEMEREPORTS::report: " . dump (@themereports);
 		
 		open( REPLIST, ">>$replist" ) or die; say TOSHELL "dump---(\$replist): " . dump($replist) . "\n\n";  
 		open( REPBLOCK, ">>$repblock" ) or die; say TOSHELL "dump---(\$repblock): " . dump($repblock) . "\n\n";
@@ -602,55 +620,68 @@ sub report # This function retrieves the results of interest from the texts file
 
 		#open( REPFILE, ">>$repfile") or die "Can't open $repfile $!";
 		
-		say TOSHELL "dump---(\@notecases): " . dump(@notecases) . "\n\n";  
+		say TOSHELL "dump---(\%notecases): " . dump( %notecases ) . "\n\n";  
 		
-		foreach $ret_ref ( @{ $notecases[ $countcase ][ $countblock ][ $countinstance ] } )
-		{
-			%retitem = %$ret_ref; say TOSHELL "dump---(\%retitem): " . dump(%retitem) . "\n\n";  
-			my $retfile = $retitem{retfile}; say TOSHELL "dump---(\$retfile): " . dump($retfile) . "\n\n";  
-			my $reporttitle = $retitem{reporttitle}; say TOSHELL "dump---(\$reporttitle): " . dump($reporttitle) . "\n\n";  
-			my $themereport = $retitem{themereport}; say TOSHELL "dump---(\$themereport): " . dump($themereport) . "\n\n";  
-			my $semaphorego = $retitem{semaphorego}; say TOSHELL "dump---(\$semaphorego): " . dump($semaphorego) . "\n\n";  
-			my $semaphorestop = $retitem{semaphorestop}; say TOSHELL "dump---(\$semaphorestop): " . dump($semaphorestop) . "\n\n";  
-			my $textpattern = $retitem{textpattern}; say TOSHELL "dump---(\$textpattern): " . dump($textpattern) . "\n\n";  
-			my $semaphore;
-			
-			
-			
-			
-			if ( -e $retfile )
-			#if ( not ( eval ( $skipreport ) ) )
+		my $numberof_simtools = scalar ( keys %{ $dowhat{simtools} } ); say $tee "\$numberof_simtools " . dump( $numberof_simtools );
+		
+		my $counttool = 1;
+		while ( $counttool <= $numberof_simtools )
+		{	
+			my $skip = $vals{$countvar}{$counttool}{skip}; say $tee "dumpinsim(\$skip): " . dump($skip);
+			if ( not ( eval ( $skipsim{$counttool} )))
 			{
-
-				open( RETFILE, "$retfile" ) or die;
-				my @lines = <RETFILE>;
-				close RETFILE;
-				foreach my $line (@lines)
+				my $tooltype = $dowhat{simtools}{$counttool}; say $tee "\$tooltype " . dump( $tooltype );
+				say $tee "\$notecases[ \$countcase ][ \$countblock ][ \$countinstance ][ \$counttool ] } : " . dump( $notecases[ $countcase ][ $countblock ][ $countinstance ][ $counttool ] );
+				foreach $ret_ref ( @{ $notecases[ $countcase ][ $countblock ][ $countinstance ][ $counttool ] } )
 				{
-					$line =~ s/^\s+//;
-					chomp $line;
-					$line = $line . " ";
-					say "\$line: $line";
-					if ( ( not ( $semaphorego ) ) or ( $line =~ m/^$semaphorego/ ) )
+					say $tee "\$ret_ref " . dump( $ret_ref );
+					%retitem = %$ret_ref; say TOSHELL "dump---(\@retitem): " . dump(@retitem) . "\n\n";  
+					my $retfile = $retitem{retfile}; say TOSHELL "dump---(\$retfile): " . dump($retfile) . "\n\n";  
+					my $reporttitle = $retitem{reporttitle}; say TOSHELL "dump---(\$reporttitle): " . dump($reporttitle) . "\n\n";  
+					my $themereport = $retitem{themereport}; say TOSHELL "dump---(\$themereport): " . dump($themereport) . "\n\n";  
+					my $semaphorego = $retitem{semaphorego}; say TOSHELL "dump---(\$semaphorego): " . dump($semaphorego) . "\n\n";  
+					my $semaphorestop = $retitem{semaphorestop}; say TOSHELL "dump---(\$semaphorestop): " . dump($semaphorestop) . "\n\n";  
+					my $textpattern = $retitem{textpattern}; say TOSHELL "dump---(\$textpattern): " . dump($textpattern) . "\n\n";  
+					my $semaphore;
+					
+					
+					if ( -e $retfile )
+					#if ( not ( eval ( $skipreport ) ) )
 					{
-						$semaphore = "on";
-					}
-					elsif ( $line =~ m/^$semaphorestop/ )
-					{
-						$semaphore = "off";
-					}
-					if ( ( $line =~ m/^$textpattern/ ) and ( $semaphore eq "on" ) )
-					{
-						print "HIT! "; say $line;
-						push ( @{ $linecontent[ $countinstance ] }, $line );
-						print REPFILE $retfile . " " . $line;
+
+						open( RETFILE, "$retfile" ) or die;
+						my @lines = <RETFILE>;
+						close RETFILE;
+						foreach my $line (@lines)
+						{
+							$line =~ s/^\s+//;
+							chomp $line;
+							$line = $line . " ";
+							say "\$line: $line";
+							if ( ( not ( $semaphorego ) ) or ( $line =~ m/^$semaphorego/ ) )
+							{
+								$semaphore = "on";
+							}
+							elsif ( $line =~ m/^$semaphorestop/ )
+							{
+								$semaphore = "off";
+							}
+							if ( ( $line =~ m/^$textpattern/ ) and ( $semaphore eq "on" ) )
+							{
+								print "HIT! "; say $line;
+								push ( @{ $mergestruct[$countcase][$countblock][ $countinstance ] }, "$retfile $line" );
+							}
+						}
 					}
+					
 				}
+				#print REPFILE "\n";
+
 			}
-			
+			$counttool++;
 		}
-		#print REPFILE "\n";
-		push ( @{ $mergestruct[$countcase][$countblock] }, @{ $linecontent[ $countinstance ] } ); say TOSHELL "\@mergestruct: " . dump(@mergestruct); 
+	
+		say TOSHELL "\@mergestruct: " . dump(@mergestruct); 
 		$countinstance++;
 	}
 	
@@ -664,10 +695,9 @@ sub report # This function retrieves the results of interest from the texts file
 		
 	foreach my $instref ( @{ $mergestruct[$countcase][$countblock] } )
 	{
-		my @instance = @{ $instref };
-		foreach (@instance)
+		foreach my $inst ( @$instref )
 		{
-			print REPFILE "$_"; say TOSHELL " INSTANCE " . dump($_);
+			print REPFILE "$inst"; #say TOSHELL " INSTANCE " . dump($_);
 		}
 		print REPFILE "\n";
 	}
