@@ -40,9 +40,9 @@ no warnings;
 #%EXPORT_TAGS = ( DEFAULT => [qw( &opt &prepare )]); # our %EXPORT_TAGS = ( 'all' => [ qw( ) ] );
 #@EXPORT   = qw(); # our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
 
-@EXPORT = qw( sim ); # our @EXPORT = qw( );
+our @EXPORT = qw( sim ); # our @EXPORT = qw( );
 
-$VERSION = '0.43.0'; # our $VERSION = '';
+$VERSION = '0.46.2'; # our $VERSION = '';
 
 
 #########################################################################################
@@ -93,9 +93,8 @@ sub sim    # This function launch the simulations in ESP-r
 	
 	%dowhat = %main::dowhat;
 
-	@simtitles = @main::simtitles; #say "dumpINSIM(\@simtitles): " . dump(@simtitles);
-	@simdata = @main::simdata;
-	@retrievedata = @main::retrievedata;
+	%simtitles = %main::simtitles; say "dumpINSIM(\@simtitles): " . dump(@simtitles);
+	%retrievedata = %main::retrievedata;
 	@keepcolumns = @main::keepcolumns;
 	@weights = @main::weights;
 	@weightsaim = @main::weightsaim;
@@ -104,7 +103,7 @@ sub sim    # This function launch the simulations in ESP-r
 	@varthemes_steps = @main::varthemes_steps;
 	@rankdata = @main::rankdata; # CUT ZZZ
 	@rankcolumn = @main::rankcolumn;
-	$reportdata = $main::reportdata;
+	%reportdata = %main::reportdata;
 	@files_to_filter = @main::files_to_filter;
 	@filter_reports = @main::filter_reports;
 	@base_columns = @main::base_columns;
@@ -146,7 +145,7 @@ sub sim    # This function launch the simulations in ESP-r
 	#if ( fileno (MORPHLIST) 
 
 	my @container;
-	
+	say TOSHELL "dump(\@instances): " . dump(@instances);
 	my $countinstance = 0;
 	foreach my $instance (@instances)
 	{
@@ -162,8 +161,6 @@ sub sim    # This function launch the simulations in ESP-r
 		my @uplift = @{ $d{uplift} }; #say TOSHELL "dump(\@uplift): " . dump(@uplift);
 		#eval($getparshere);
 		
-		my $skip = $vals{$countvar}{skip}; say TOSHELL "dumpinsim(\$skip): " . dump($skip);
-		
 		my $rootname = Sim::OPT::getrootname(\@rootnames, $countcase); #say TOSHELL "dump(\$rootname): " . dump($rootname);
 		my @blockelts = Sim::OPT::getblockelts(\@sweeps, $countcase, $countblock); #say TOSHELL "dumpIN( \@blockelts) " . dump(@blockelts);
 		my @blocks = Sim::OPT::getblocks(\@sweeps, $countcase);  #say TOSHELL "dumpIN( \@blocks) " . dump(@blocks);
@@ -189,74 +186,85 @@ sub sim    # This function launch the simulations in ESP-r
 		#	push ( @simcases, $to ); say TOSHELL "simcases: " . dump(@simcases);
 		#	print SIMLIST "$to\n";
 		#}
-
+		
+		my $numberof_simtools = scalar ( keys %{ $dowhat{simtools} } ); say TOSHELL "\$numberof_simtools " . dump( $numberof_simtools );
 		my $simelt = $to;
-		if ( not ( eval ( $skipsim )))
-		{
-			
-			my $countsim = 0;
-			foreach my $date_to_sim ( @simtitles )
+		
+		my $counttool = 1;
+		while ( $counttool <= $numberof_simtools )
+		{	
+			my $skip = $vals{$countvar}{$counttool}{skip}; say TOSHELL "dumpinsim(\$skip): " . dump($skip);
+			if ( not ( eval ( $skipsim{$counttool} )))
 			{
-				my @simdat = @{ $simdata[ $countsim ] }; say TOSHELL "dump(\@simdat): " . dump(@simdat); 
-				my $begin = $simdat[0]; say TOSHELL "dump(\$begin): " . dump($begin); 
-				my $end = $simdat[1]; say TOSHELL "dump(\$end): " . dump($end); 
-				my $before = $simdat[2]; say TOSHELL "dump(\$before): " . dump($before); 
-				my $step = $simdat[3]; say TOSHELL "dump(\$step): " . dump($step); 
-				my $resfile = "$simelt-$date_to_sim.res";
-				my $flfile = "$simelt-$date_to_sim.fl";
-				push (@ress, $resfile); # ERASE
-				push (@flfs, $flfile); # ERASE
+				my $tooltype = $dowhat{simtools}{$counttool}; say TOSHELL "\$tooltype " . dump( $tooltype );
 				
-				#if ( fileno (SIMLIST) )
-				#if (not (-e $simlist ) )
-				#{
-				#	if ( $countblock == 0 )
-				#	{
-						open( SIMLIST, ">>$simlist") or die;
-				#	}
-				#	else 
-				#	{
-				#		open( SIMLIST, ">>$simlist") or die;
-				#	}
-				#}
-				
-				#if ( fileno (SIMBLOCK) )
-				if (not (-e $simblock ) )
-				{
-					if ( $countblock == 0 )
+				if ( $tooltype eq "esp-r" )
+				{	
+					say TOSHELL "dump(\%simtitles): " . dump( %simtitles ); 
+					say TOSHELL "dump(\$simtitles{\$counttool}): " . dump( $simtitles{$counttool} ); 
+					say TOSHELL "dump(\@{ \$simtitles{\$counttool}): " . dump( @{ $simtitles{$counttool} } ); 	
+					my $countsim = 0;		
+					foreach my $simtitle_ref ( @{ $simtitles{$counttool} } )
 					{
-						open( SIMBLOCK, ">>$simblock"); # or die;
-					}
-					else 
-					{
-						open( SIMBLOCK, ">>$simblock"); # or die;
-					}
-				}
-				
-				#say "INSIM1\$countcase : " . dump($countcase);
-				#say "INSIM1\@rootnames : " . dump(@rootnames);
-				#say "INSIM1\$countblock : " . dump($countblock);
-				#say "INSIM1\@sweeps : " . dump(@sweeps);
-				#say "INSIM1\@varinumbers : " . dump(@varinumbers);
-				#say "INSIM1\@miditers : " . dump(@miditers);
-				#say "INSIM1\@winneritems : " . dump(@winneritems);
-				#say "INSIM1\@morphcases : " . dump(@morphcases);
-				#say "INSIM1\@morphstruct : " . dump(@morphstruct);
-				
-				push ( @{ $simstruct[ $countcase ][ $countblock ][ $countinstance ] }, $resfile );
-				print SIMBLOCK "$resfile\n";
-			
-				if ( ( not ( $resfile ~~ @simcases ) ) and ( not ( -e $resfile ) ) )
-				{
-					push ( @simcases, $resfile );
-					print SIMLIST "$resfile\n";
+						my $date_to_sim = $simtitle_ref->[0]; say TOSHELL "dump(\$date_to_sim ): " . dump( $date_to_sim ); 
+						my $begin = $simtitle_ref->[1]; say TOSHELL "dump(\$begin): " . dump($begin); 
+						my $end = $simtitle_ref->[2]; say TOSHELL "dump(\$end): " . dump($end); 
+						my $before = $simtitle_ref->[3]; say TOSHELL "dump(\$before): " . dump($before); 
+						my $step = $simtitle_ref->[4]; say TOSHELL "dump(\$step): " . dump($step); 
 						
-					unless ( $preventsim eq "y" )
-					{
-						if ( $simnetwork eq "y" )
+						my $resfile = "$simelt-$date_to_sim-$tooltype.res"; say TOSHELL "dump(\$resfile): " . dump($resfile); 
+						my $flfile = "$simelt-$date_to_sim-$tooltype.fl"; say TOSHELL "dump(\$flfile): " . dump($flfile); 
+
+						#if ( fileno (SIMLIST) )
+						#if (not (-e $simlist ) )
+						#{
+						#	if ( $countblock == 0 )
+						#	{
+								open( SIMLIST, ">>$simlist") or die;
+						#	}
+						#	else 
+						#	{
+						#		open( SIMLIST, ">>$simlist") or die;
+						#	}
+						#}
+						
+						#if ( fileno (SIMBLOCK) )
+						if (not (-e $simblock ) )
 						{
-							say "#Simulating case " . ($countcase + 1) . ", block " . ($countblock + 1) . ", parameter $countvar at iteration $countstep. Instance $countinstance: writing $resfile and $flfile. " ;
-							my $printthis =	
+							if ( $countblock == 0 )
+							{
+								open( SIMBLOCK, ">>$simblock"); # or die;
+							}
+							else 
+							{
+								open( SIMBLOCK, ">>$simblock"); # or die;
+							}
+						}
+						
+						#say "INSIM1\$countcase : " . dump($countcase);
+						#say "INSIM1\@rootnames : " . dump(@rootnames);
+						#say "INSIM1\$countblock : " . dump($countblock);
+						#say "INSIM1\@sweeps : " . dump(@sweeps);
+						#say "INSIM1\@varinumbers : " . dump(@varinumbers);
+						#say "INSIM1\@miditers : " . dump(@miditers);
+						#say "INSIM1\@winneritems : " . dump(@winneritems);
+						#say "INSIM1\@morphcases : " . dump(@morphcases);
+						#say "INSIM1\@morphstruct : " . dump(@morphstruct);
+						
+						push ( @{ $simstruct[ $countcase ][ $countblock ][ $countinstance ][$counttool] }, $resfile );
+						print SIMBLOCK "$resfile\n";
+					
+						if ( ( not ( $resfile ~~ @simcases ) ) and ( not ( -e $resfile ) ) )
+						{
+							push ( @simcases, $resfile );
+							print SIMLIST "$resfile\n";
+								
+							unless ( $preventsim eq "y" )
+							{
+								if ( $simnetwork eq "y" )
+								{
+									say "#Simulating case " . ($countcase + 1) . ", block " . ($countblock + 1) . ", parameter $countvar at iteration $countstep for tool $tooltype. Instance $countinstance: writing $resfile and $flfile." ;
+									my $printthis =	
 "bps -file $simelt/cfg/$fileconfig -mode script<<XXX
 
 c
@@ -279,21 +287,21 @@ y
 -
 -
 XXX
-";
-							if ($exeonfiles eq "y") 
-							{
-								print `$printthis`;
-							}
-							print TOSHELL " 	
-	#Simulating case " . ($countcase + 1) . ", block " . ($countblock + 1) . ", parameter $countvar at iteration $countstep. Instance $countinstance.\
-	$printthis
-	\n";
-							print OUTFILE "TWO, $resfile\n";
-						}	
-						else # THAT IS: if ( $simnetwork eq "n" )
-						{
-							say "#Simulating case " . ($countcase + 1) . ", block " . ($countblock + 1) . ", parameter $countvar at iteration $countstep. Instance $countinstance: writing $resfile. " ;
-							my $printthis =
+	";
+									if ($exeonfiles eq "y") 
+									{
+										print `$printthis`;
+									}
+									print TOSHELL " 	
+			#Simulating case " . ($countcase + 1) . ", block " . ($countblock + 1) . ", parameter $countvar at iteration $countstep. Instance $countinstance.\
+			$printthis
+			\n";
+									print OUTFILE "TWO, $resfile\n";
+								}	
+								else #  if ( $simnetwork eq "n" )
+								{
+									say "#Simulating case " . ($countcase + 1) . ", block " . ($countblock + 1) . ", parameter $countvar at iteration $countstep for tool $tooltype. Instance $countinstance: writing $resfile. " ;
+									my $printthis =
 "bps -file $simelt/cfg/$fileconfig -mode script<<XXX
 
 c
@@ -316,20 +324,129 @@ y
 -
 XXX
 ";
-							if ($exeonfiles eq "y") 
+									if ($exeonfiles eq "y") 
+									{
+										print `$printthis`;
+									}
+									print TOSHELL "  
+$printthis
+";
+								}					
+							}		
+						}							
+						$countsim++;
+					}
+				}
+				elsif ( $tooltype eq "energyplus" )
+				{	# TO DO: POSSIBILITY TO SPECIFY LINE AND ELEMENT OF TEXT SUBSTITUTIONS.
+					my $countsim = 0;			
+					foreach my $simtitle_ref ( @simtitles )
+					{
+						my $date_to_sim = $simtitle_ref->[0]; say TOSHELL "dump(\$date_to_sim ): " . dump( $date_to_sim ); 
+						my $begin = $simtitle_ref->[1]; say TOSHELL "dump(\$begin): " . dump($begin); 
+						my $end = $simtitle_ref->[2]; say TOSHELL "dump(\$end): " . dump($end); 
+						my $before = $simtitle_ref->[3]; say TOSHELL "dump(\$before): " . dump($before); 
+						my $step = $simtitle_ref->[4]; say TOSHELL "dump(\$step): " . dump($step); 
+						 
+						my $epw = $simtitle_ref->[5]; say TOSHELL "dump(\$epw ): " . dump( $epw ); 
+						my $epwfile = $mypath . "/" . $epw; say TOSHELL"\$genfile " . dump( $genfile );
+						my $epoldfile = $simtitle_ref->[6]; say TOSHELL "dump(\$epoldfile ): " . dump( $epoldfile ); 
+						my $epnewfile = $simtitle_ref->[7]; say TOSHELL "dump(\$epnewfile ): " . dump( $epnewfile ); 
+						my @simdos = @{ $simtitle_ref };
+						my @changes = @simdos[ 8..$#simdos ]; say TOSHELL "dump(\$epnewfile ): " . dump( $epnewfile ); 
+						
+						open ( EPOLDFILE, "$epoldfile" ) or die;
+						my @sourcecontents = <EPOLDFILE>;
+						close EPOLDFILE; say TOSHELL "dump(\@sourcecontents ): " . dump( @sourcecontents ); 
+						
+						open ( EPNEWFILE, ">$epnewfile" ) or die;
+						foreach my $row ( @sourcecontents )
+						{
+							foreach my $change ( @changes )
 							{
-								print `$printthis`;
+								my $source = $change->[0]; say T say TOSHELL "dump(\$source ): " . dump( $source ); 
+								my $target = $change->[1]; say TOSHELL "dump(\$target ): " . dump( $target ); say TOSHELL "dump(\$rowBEFORE ): " . dump( $epnewfile ); 
+								$row =~ s/$source/$target/ ; say TOSHELL "dump(\$rowAFTER ): " . dump( $row ); 
+								print EPNEWFILE $row;
 							}
-							print TOSHELL "  
-	$printthis
-	";
-						}					
-					}		
+						}	
+						close EPNEWFILE;
+						
+						my $file_eplus = "$to/$file_eplus";  say TOSHELL "dump(\$file_eplus ): " . dump( $file_eplus ); 
+						
+						my $simelt =~ s/$mypath/$mypath\/Output/; say TOSHELL "dump(\$simelt ): " . dump( $simelt ); 
+						my $resfile = "$simelt/$epnewfile.eso"; # ZZZ: CHECK say TOSHELL "dump(\$resfile ): " . dump( $resfile ); 
+						
+						if (not (-e $simblock ) )
+						{
+							if ( $countblock == 0 )
+							{
+								open( SIMBLOCK, ">>$simblock"); # or die;
+							}
+							else 
+							{
+								open( SIMBLOCK, ">>$simblock"); # or die;
+							}
+						}
+						
+						if (not (-e $retblock ) )
+						{
+							if ( $countblock == 0 )
+							{
+								open( RETBLOCK, ">>$retblock"); # or die;
+							}
+							else 
+							{
+								open( RETBLOCK, ">>$retblock"); # or die;
+							}
+						}
+						
+						push ( @{ $simstruct[ $countcase ][ $countblock ][ $countinstance ][ $counttool ] }, $resfile );
+						push ( @{ $retstruct[ $countcase ][ $countblock ][ $countinstance ][ $counttool ] }, $resfile );
+						print SIMBLOCK "$resfile\n";
+					
+						if ( ( not ( $resfile ~~ @retcases ) ) and ( not ( -e $resfile ) ) )
+						{
+							push ( @simcases, $resfile );
+							push ( @retcases, $resfile );
+							print SIMLIST "$resfile\n";
+							print RETLIST "$resfile\n";
+								
+							unless ( $preventsim eq "y" )
+							{
+										
+								open ( OLDFILEEPLUS, $epoldfile ) or die;
+								my @oldlines = <OLDFILEEPLUS>;
+								close OLDFILEEPLUS;
+								
+								open ( NEWFILEEPLUS, ">$epnewfile" ) or die;
+								
+								foreach my $line ( @oldlines )
+								{
+									foreach my $elt ( @changes )
+									{
+										my $old = $elt->[0];
+										my $new = $elt->[1];
+										$line =~ s/$old/$new/;
+									}
+									print NEWFILEEPLUS $line;
+								}
+								close NEWFILEEPLUS;
+								
+								unless ( $exeonfiles eq "n" )
+								{
+									`runenergyplus $epnewfile $epwfile`;
+								}
+								print TOSHELL "runenergyplus $epnewfile $epwfile\n";
+								say "#Simulating case " . ($countcase + 1) . ", block " . ($countblock + 1) . ", parameter $countvar at iteration $countstep for tool $tooltype. Instance $countinstance: writing $resfile. " ;										
+							}		
+						}
+						$countsim++;
+					}
 				}
-				$countsim++;
 			}
-		
-		}
+			$counttool++;
+		}	
 		$countinstance++;
 	}
 	close SIMLIST;
