@@ -6,10 +6,10 @@
 ############################################################################################################
 ####### BEGINNING OF DATA FOR THE MORPH.pm, RETRIEVE.pm, REPORT.pm AND Descenf.pm MODULES (TILL END) #######
 
-$mypath = "/home/luca/modtest" ;# path of the directory in which you are going to work
+$mypath = "/home/luca/tryfolder" ;# path of the directory in which you are going to work
 
-@sweeps = ( [ [ 1 ] ] );
-#@sweeps = ( [ [ 1, 2, 3, 4 ] ] );
+#@sweeps = ( [ [ 1 ] ] );
+@sweeps = ( [ [ 1, 2, 3, 4, 5, 6 ] ] );
 #@sweeps = ( [ [ 1, 2, 3], [2, 3, 4] , [ 3, 4, 5], [4, 5, 6 ] ] );
 #@sweeps = ( [ [ 1, 2, 3, 4, 5, 6, 7, 8 ] ] );
 # OR: ( [ [1, 2], [2, 3] ] ); # OR: @sweeps = ( [ [1, 2, 3, 4], [3, 4, 5, 1], [5, 1, 2, 3] ], [ [1, 2], [2, 3] ] ); # OR: @sweeps = ( [ [1, 2, 3, 4], [3, 4, 5, 1], [5, 1, 2, 3] ] );
@@ -20,16 +20,16 @@ $mypath = "/home/luca/modtest" ;# path of the directory in which you are going t
 # @sweeps IS NOT OVERRIDDEN ON THE BASIS OF WHAT IS SPECIFIED IN @chanceseed AND @caseseed. 
 # IT HAS TO BE UNSPECIFIED IF THE SEARCH STRUCTURE HAS TO BE CALCULATE BY THE PROGRAM. @sweepseed MAY BE SPECIFIED IN ITS PLACE.
 
-@varinumbers = ( { 1 => 3 } );
+#@varinumbers = ( { 1 => 3 } );
 #@varinumbers = ( { 1 => 3, 2 => 3, 3 => 3, 4 => 3 } ); #THIS IS THE DEFAULT. THESE VALUES CAN BE OVERRIDDEN BELOW, IN THE PARAMETERS' SPECIFICATIONS
-#@varinumbers = ( { 1 => 3, 2 => 3, 3 => 3, 4 => 3, 5 => 3, 6 => 3 } ); #THIS IS THE DEFAULT. THESE VALUES CAN BE OVERRIDDEN BELOW, IN THE PARAMETERS' SPECIFICATIONS
+@varinumbers = ( { 1 => 3, 2 => 3, 3 => 3, 4 => 3, 5 => 3, 6 => 9 } ); #THIS IS THE DEFAULT. THESE VALUES CAN BE OVERRIDDEN BELOW, IN THE PARAMETERS' SPECIFICATIONS
 #@varinumbers = ( { 1 => 2, 2 => 2, 3 => 2, 4 => 2, 5 => 2, 6 => 9, 7 => 2, 8 => 2 } ); #THIS IS THE DEFAULT. THESE VALUES CAN BE OVERRIDDEN BELOW, IN THE PARAMETERS' SPECIFICATIONS
 # OR: @varinumbers = ( { 1 => '3', 2 => '3', 3 => '3', 4 => '3', 5 => '3' } ); # OR: @varinumbers = ( { 1 => '3', 2 => '3', 3 => '3', 4 => '3', 5 => '3' }, { 1 => '3', 2 => '3', 3 => '3' } );
 # IN THIS ARRAY OF HASHES (DICTIONARIES) THE NUMBER OF ITERATIONS FOR EACH VARIABLES ARE SPECIFIED.
 
-@mediumiters = ( { 1 => 2 } );
+#@mediumiters = ( { 1 => 2 } );
 #@mediumiters = ( { 1 => 2, 2 => 2, 3 => 2, 4 => 2 } );
-#@mediumiters = ( { 1 => 2, 2 => 2, 3 => 2, 4 => 2, 5 => 2, 6 => 2 } );
+@mediumiters = ( { 1 => 2, 2 => 2, 3 => 2, 4 => 2, 5 => 2, 6 => 5 } );
 #@mediumiters = ( { 1 => 2, 2 => 2, 3 => 2, 4 => 2, 5 => 1, 6 => 5, 7 => 1 , 8 => 1 } );
 #mediumiters = ( { 1 => 2, 2 => 2, 3 => 2, 4 => 2, 5 => 1, 6 => 5, 7 => 1 , 8 => 1 } ); # OR: @mediumiters = ( { 1 => 2, 2 => 2, 3 => 2 } );
 # IN THIS ARRAY OF HASHES (DICTIONARIES) THE BASE ITERATION FOR EACH VARIABLES ARE SPECIFIED. 
@@ -47,6 +47,12 @@ eraseres => "n", # erase .res and .fl files as they are created or leave them as
 substitutenames => "n", # substitute names (convert) in non-filtered reports? (UNTESTED SINCE EARLY VERSIONS.)
 filterconverted => "n", # filter already converted reports? (UNTESTED SINCE EARLY VERSIONS.)
 make3dtable => "n", # make table to be plotted in 3D? (UNTESTED SINCE EARLY VERSIONS.)
+overwrite_models => { 1 => "n" },
+actonexisting_models => { 1 => "y" },
+simtools => { 1 => "esp-r", 
+#2 => "energyplus" 
+},
+#reptools => { 1 => "esp-r" },
 ); # 11) THIS MUST BE "y" TO PERFORM BLOCK SEARCH. It checks if it is possible to launch a block search, and if it is does it.
 
 $fileconfig = "boxform.cfg"; # name of the configuration file of the model, which will reside in the "./cfg/" directory in your model's directory.
@@ -55,30 +61,21 @@ $simnetwork = "n"; # is there a mass/flow network? This information regards the
 $exeonfiles = "y";
 $preventsim = "n";
 
-@simtitles = 
-( 
-"feb01-feb08" , "jul01-jul08"
-);
-# OR: ("mar1-apr30", "mar1-apr30" ); 
-# write here the name of the time periods will be taken into account in the simulations.
-# This will decide the name of the simulation files. Short names are better.
+$simtitles{1} = [ 
+[ "feb01-feb08", "1 2", "8 2", "20", "1" ], 
+[ "jul01-jul08", "1 7", "8 7", "20", "1" ]
+];
 
-#$vals{skipsim} = " ( ( $to =~ /_1-2/ ) or ( $to =~ /_2-2/ ) or ( $to =~ /_3-2/ ) or ( $to =~ /_4-2/ ) or ( $to =~ /_5-2/ ) or ( $to =~ /_6-2/ ) ) ";
-#$vals{skipsim} = " ( ( \$to =~ /_1-2/ ) or ( \$to =~ /_2-2/ ) or ( \$to =~ /_3-2/ ) or ( \$to =~ /_4-2/ ) or ( \$to =~ /_5-2/ ) or ( \$to =~ /_6-3/ ) or ( \$to =~ /_6-5/ ) ) ";
+#$simtitles{2} = [ 
+#[ "feb01-feb08", "1 2", "8 2", "20", "1", "milan.epw", "boxform.idf", "boxform_feb.idf", [ "FullInteriorAndExterior", "FullInteriorAndExteriorWithReflections" ], [ "4;   !- Time Step in Hour", "1;   !- Time Step in Hour" ], [ "1, 1,   !- Begin Month", "2, 1,   !- Begin Month" ], [ "12,31,   !- End Month", " 2, 7,   !- End Month" ] ], 
+#[ "jul01-jul08", "1 7", "8 7", "20", "1", "milan.epw", "boxform.idf", "boxform_jul.idf",[ "FullInteriorAndExterior", "FullInteriorAndExteriorWithReflections" ], [ "4;   !- Time Step in Hour", "1;   !- Time Step in Hour" ], [ "1, 1,   !- Begin Month", "7, 1,   !- Begin Month" ], [ "12,31,   !- End Month", " 7, 7,   !- End Month" ] ],
+#];
 
-@simdata = 
-( [ 
-"1 2", "8 2", "20", "1",
-],
+#$vals{1}{skipsim} = " ( ( $to =~ /_1-2/ ) or ( $to =~ /_2-2/ ) or ( $to =~ /_3-2/ ) or ( $to =~ /_4-2/ ) or ( $to =~ /_5-2/ ) or ( $to =~ /_6-2/ ) ) ";
+#$vals{1}{skipsim} = " ( ( \$to =~ /_1-2/ ) or ( \$to =~ /_2-2/ ) or ( \$to =~ /_3-2/ ) or ( \$to =~ /_4-2/ ) or ( \$to =~ /_5-2/ ) or ( \$to =~ /_6-3/ ) or ( \$to =~ /_6-5/ ) ) ";
+
+$retrievedata{1} = 
 [ 
-"1 7", "8 7", "20", "1" 
-] ); 
-#OR: (["1 3", "30 4", "20", "1"],["1 3", "30 4", "20", "1"]); 
-# Here put the data this way: "starting-month_1 starting-day_1", "ending-month_1 ending-day_1", "start-up-period-duration_1", "time/steps-hour_1", "starting-month_2"starting-day_2", "ending-month_2 ending-day_2", "start-up-period-duration_2", "time/steps-hour_2", ..., "starting-month_n starting-day_n", "ending-month_n ending-day_n", "start-up-period-duration_n", "time/steps-hour_n"
-# THESE ARE THE PERIODS TO BE REPORTED. THERE IS A POINT TO POINT CORRENSPONDENCE WITH @simdata
-
-@retrievedata = 
-( 
 [ 
 [ 
 "1 2 1", "7 2 24", "1" 
@@ -89,7 +86,9 @@ $preventsim = "n";
 "1 7 1", "7 7 24", "1" 
 ] 
 ]
-); 
+]; 
+
+
 # OR: ( [["1 3 1", "31 3 24", "1"] , ["1 3 1", "31 3 24", "1"]], [["1 4 1", "30 4 24", "1"] , ["1 4 1", "30 4 24", "1"]] ); 
 # start data to retrieve for temps; end data to retrieve for temps.
 # THESE ARE THE PERIODS TO BE REPORTED. THERE IS A POINT TO POINT CORRESPONDENCE WITH @reporttiles
@@ -126,7 +125,7 @@ $preventsim = "n";
 #0, 0, 3, 0
 #); # THIS DATA ARE POINT-TO- POINT RELATIVE TO THE ARRAY ABOVE AND TELLS WHAT FILE COLUMN THE RANKING HAS TO BE BASED ON: 3 for max air temps, 5 for min air temps, 7 for mean air temps, 8 for resultant max temps, 10 for resultant min temps, 12 for resultant mean temps - # (NOTE: UNMANTAINED FROM VERSION 0.5 ON).
 
-$reportdata = # THERE IS A POINT-TO POINT CORRESPONDENCE TO THE ITEMS IN @retrievedata
+$reportdata{1} = # THERE IS A POINT-TO POINT CORRESPONDENCE TO THE ITEMS IN @retrievedata
 [ 
 [ 
 [ 
@@ -164,7 +163,8 @@ $reportdata = # THERE IS A POINT-TO POINT CORRESPONDENCE TO THE ITEMS IN @retrie
 	}
 ] 
 ]
-]; 
+];
+
 
 #$vals{skipfile} = "skipfile.txt";
 #$vals{skipreport} = " ( ( $simtitle =~ /_1-2/ ) or ( $simtitle =~ /_2-2/ ) or ( $simtitle =~ /_3-2/ ) or ( $simtitle =~ /_4-2/ ) or ( $simtitle =~ /_5-2/ ) or ( $simtitle =~ /_6-2/ ) ) ";
@@ -206,33 +206,36 @@ $reportdata = # THERE IS A POINT-TO POINT CORRESPONDENCE TO THE ITEMS IN @retrie
 
 ######################### PARAMETER 1. #############################
 
-$vals{1}{applytype} = [ [ "change_groundreflectance", "boxform.cfg", "boxform.cfg", "a" ] ] ; #  @applytype(n) = (["type_of_change", "your_test_file", "file_name_to_which_the_former_will_be_copied_to", "zone_letter"]), 
-# the following morphing operations are available: "translation", "rotation", "rotationz", "surface_translation", "vertices_shift", 
-# "surface_rotation", "warping", "construction_reassignment", "thickness_change", "obs_modification", "generic_change", "vary_controls", “vary_net”, 
-# "change_groundreflectance", "generic_changeandconstrain", "vertex_translation"
-$vals{1}{general_variables} = 
+$vals{1}{1}{applytype} = [ [ "obs_modify", "boxform.cfg", "boxform.cfg", "a" ] ] ; #  @applytype(n) = (["type_of_change", "your_test_file", "file_name_to_which_the_former_will_be_copied_to", "zone_letter"]), 
+# the following morphing operations are available: "translate", "rotate", "rotatez", "surface_translate", "shift_vertices", 
+# "rotate_surface", "warping", "construction_reassign", "change_thickness", "obs_modify", "generic_change", "vary_controls", “vary_net”, 
+# "change_groundreflectance", "generic_changeandconstrain", "translate_vertices", "change_climate"
+$vals{1}{1}{general_variables} = 
 [
 "y", # $generate(n) eq "n" # (if the models deriving from this runs will not be generating new models) or y (if they will be generating new models).
 "n" #if $sequencer eq "y", or "last" (of a sequence) iteration between non-continuous cases wanted.  The first gets appended to the middle(s) and to he last. Otherwise, "n".
 ];
-$vals{1}{change_groundreflectance} =  
+$vals{1}{1}{obs_modify} = 
+[   
 [ 
-[ 0.65, [ 0.50, 0.80 ] ] # [ base value, [ low, high ] ]; OR: [ base value, half-range ];
+"/zones/box.geo",
+[ "e"  , "a", [ [ 0, -0.02, 0 ], [ 0, -1.51, 0 ] ] ], # IT MODIFIES THE ORIGIN OF OBSTRUCTION "h"
+[ "e"  , "b", [ [ 0, 0.01, 0 ], [ 0, 1.50, 0 ] ] ], # IT MODIFIES THE DIMENSION OF THE SAME OBSTRUCTION ABOVE
+]
 ];
 
-
 ######################### PARAMETER 2. #############################
 
-$vals{2}{applytype} = [ [ "obs_modification", "boxform.cfg", "boxform.cfg", "a" ] ] ; #  @applytype(n) = (["type_of_change", "your_test_file", "file_name_to_which_the_former_will_be_copied_to", "zone_letter"]), 
+$vals{1}{2}{applytype} = [ [ "obs_modify", "boxform.cfg", "boxform.cfg", "a" ] ] ; #  @applytype(n) = (["type_of_change", "your_test_file", "file_name_to_which_the_former_will_be_copied_to", "zone_letter"]), 
 # the following morphing operations are available: "translation", "rotation", "rotationz", "surface_translation", "vertices_shift", 
 # "surface_rotation", "warping", "construction_reassignment", "thickness_change", "obs_modification", "generic_change", "vary_controls", “vary_net”, 
 # "change_groundreflectance", "generic_changeandconstrain"
-$vals{2}{general_variables} = 
+$vals{1}{2}{general_variables} = 
 [
 "y", # $generate(n) eq "n" # (if the models deriving from this runs will not be generating new models) or y (if they will be generating new models).
 "n" #if $sequencer eq "y", or "last" (of a sequence) iteration between non-continuous cases wanted.  The first gets appended to the middle(s) and to he last. Otherwise, "n".
 ];
-$vals{2}{obs_modify} = 
+$vals{1}{2}{obs_modify} = 
 [   
 [ 
 "/zones/box.geo", # GEO FILE IN WHICH THE OBSTRUCTIION
@@ -240,7 +243,7 @@ $vals{2}{obs_modify} =
 [ "f"  , "b", [ [ 0, 0.01, 0 ], [ 0, 1.50, 0 ] ] ], # IT MODIFIES THE DIMENSION OF THE SAME OBSTRUCTION ABOVE
 ]
 ];
-#$vals{2}{skipop}  = [ [ " ( ( \$to =~ /_1-2/ ) or ( \$to =~ /_2-2/ ) or ( \$to =~ /_3-2/ ) or ( \$to =~ /_4-2/ ) or ( \$to =~ /_5-2/ ) or ( \$to =~ /_6-2/ ) ) " ] ];
+#$vals{1}{2}{skipop}  = [ [ " ( ( \$to =~ /_1-2/ ) or ( \$to =~ /_2-2/ ) or ( \$to =~ /_3-2/ ) or ( \$to =~ /_4-2/ ) or ( \$to =~ /_5-2/ ) or ( \$to =~ /_6-2/ ) ) " ] ];
 # [ 
 # what to modify? "a" for origin, "b" for dimensions, "c" for z_rotation, "d" for y_rotation, "g" for construction, "h" for opacity, "t" for transform	
 # enter value or values corresponding to the above. If origin coordinates of one extreme of the translation. 
@@ -251,16 +254,16 @@ $vals{2}{obs_modify} =
 
 ######################### PARAMETER 3. #############################
 
-$vals{3}{applytype} = [ [ "obs_modification", "boxform.cfg", "boxform.cfg", "a" ] ] ; #  @applytype(n) = (["type_of_change", "your_test_file", "file_name_to_which_the_former_will_be_copied_to", "zone_letter"]), 
+$vals{1}{3}{applytype} = [ [ "obs_modify", "boxform.cfg", "boxform.cfg", "a" ] ] ; #  @applytype(n) = (["type_of_change", "your_test_file", "file_name_to_which_the_former_will_be_copied_to", "zone_letter"]), 
 # the following morphing operations are available: "translation", "rotation", "rotationz", "surface_translation", "vertices_shift", 
 # "surface_rotation", "warping", "construction_reassignment", "thickness_change", "obs_modification", "generic_change", "vary_controls", “vary_net”, 
 # "change_groundreflectance", "generic_changeandconstrain"
-$vals{3}{general_variables} = 
+$vals{1}{3}{general_variables} = 
 [
 "y", # $generate(n) eq "n" # (if the models deriving from this runs will not be generating new models) or y (if they will be generating new models).
 "n" #if $sequencer eq "y", or "last" (of a sequence) iteration between non-continuous cases wanted.  The first gets appended to the middle(s) and to he last. Otherwise, "n".
 ];
-$vals{3}{obs_modify} = 
+$vals{1}{3}{obs_modify} = 
 [   
 [ 
 "/zones/box.geo",
@@ -268,7 +271,7 @@ $vals{3}{obs_modify} =
 [ "g"  , "b", [ [ 0, 0.01, 0 ], [ 0, 1.50, 0 ] ] ], # IT MODIFIES THE DIMENSION OF THE SAME OBSTRUCTION ABOVE
 ]
 ];
-#$vals{3}{skipop}  = [ [ " ( ( \$to =~ /_1-2/ ) or ( \$to =~ /_2-2/ ) or ( \$to =~ /_3-2/ ) or ( \$to =~ /_4-2/ ) or ( \$to =~ /_5-2/ ) or ( \$to =~ /_6-2/ ) ) " ] ];
+#$vals{1}{3}{skipop}  = [ [ " ( ( \$to =~ /_1-2/ ) or ( \$to =~ /_2-2/ ) or ( \$to =~ /_3-2/ ) or ( \$to =~ /_4-2/ ) or ( \$to =~ /_5-2/ ) or ( \$to =~ /_6-2/ ) ) " ] ];
 # [ 
 # what to modify? "a" for origin, "b" for dimensions, "c" for z_rotation, "d" for y_rotation, "g" for construction, "h" for opacity, "t" for transform	
 # enter value or values corresponding to the above. If origin coordinates of one extreme of the translation. 
@@ -279,16 +282,16 @@ $vals{3}{obs_modify} =
 
 ######################### PARAMETER 4. #############################
 
-$vals{4}{applytype} = [ [ "obs_modification", "boxform.cfg", "boxform.cfg", "a" ] ] ; #  @applytype(n) = (["type_of_change", "your_test_file", "file_name_to_which_the_former_will_be_copied_to", "zone_letter"]), 
+$vals{1}{4}{applytype} = [ [ "obs_modify", "boxform.cfg", "boxform.cfg", "a" ] ] ; #  @applytype(n) = (["type_of_change", "your_test_file", "file_name_to_which_the_former_will_be_copied_to", "zone_letter"]), 
 # the following morphing operations are available: "translation", "rotation", "rotationz", "surface_translation", "vertices_shift", 
 # "surface_rotation", "warping", "construction_reassignment", "thickness_change", "obs_modification", "generic_change", "vary_controls", “vary_net”, 
 # "change_groundreflectance", "generic_changeandconstrain"
-$vals{4}{general_variables} = 
+$vals{1}{4}{general_variables} = 
 [
 "n", # $generate(n) eq "n" # (if the models deriving from this runs will not be generating new models) or y (if they will be generating new models).
 "n" #if $sequencer eq "y", or "last" (of a sequence) iteration between non-continuous cases wanted.  The first gets appended to the middle(s) and to he last. Otherwise, "n".
 ];
-$vals{4}{obs_modify} = 
+$vals{1}{4}{obs_modify} = 
 [   
 [ 
 "/zones/box.geo",
@@ -296,7 +299,7 @@ $vals{4}{obs_modify} =
 [ "h"  , "b", [ [ 0, 0.01, 0 ], [ 0, 1.50, 0 ] ] ], # IT MODIFIES THE DIMENSION OF THE SAME OBSTRUCTION ABOVE
 ]
 ];
-#$vals{4}{skipop}  = [ [ " ( ( \$to =~ /_1-2/ ) or ( \$to =~ /_2-2/ ) or ( \$to =~ /_3-2/ ) or ( \$to =~ /_4-2/ ) or ( \$to =~ /_5-2/ ) or ( \$to =~ /_6-2/ ) ) " ] ];
+#$vals{1}{4}{skipop}  = [ [ " ( ( \$to =~ /_1-2/ ) or ( \$to =~ /_2-2/ ) or ( \$to =~ /_3-2/ ) or ( \$to =~ /_4-2/ ) or ( \$to =~ /_5-2/ ) or ( \$to =~ /_6-2/ ) ) " ] ];
 # [ 
 # what to modify? "a" for origin, "b" for dimensions, "c" for z_rotation, "d" for y_rotation, "g" for construction, "h" for opacity, "t" for transform	
 # enter value or values corresponding to the above. If origin coordinates of one extreme of the translation. 
@@ -307,23 +310,23 @@ $vals{4}{obs_modify} =
 
 ######################### PARAMETER 5. #############################
 
-$vals{5}{applytype} = [ [ "obs_modification", "boxform.cfg", "boxform.cfg", "a" ] ] ; #  @applytype(n) = (["type_of_change", "your_test_file", "file_name_to_which_the_former_will_be_copied_to", "zone_letter"]), 
+$vals{1}{5}{applytype} = [ [ "obs_modify", "boxform.cfg", "boxform.cfg", "a" ] ] ; #  @applytype(n) = (["type_of_change", "your_test_file", "file_name_to_which_the_former_will_be_copied_to", "zone_letter"]), 
 # the following morphing operations are available: "translation", "rotation", "rotationz", "surface_translation", "vertices_shift", 
 # "surface_rotation", "warping", "construction_reassignment", "thickness_change", "obs_modification", "generic_change", "vary_controls", “vary_net”, 
 # "change_groundreflectance", "generic_changeandconstrain"
-$vals{5}{general_variables} = 
+$vals{1}{5}{general_variables} = 
 [
 "y", # $generate(n) eq "n" # (if the models deriving from this runs will not be generating new models) or y (if they will be generating new models).
 "n" #if $sequencer eq "y", or "last" (of a sequence) iteration between non-continuous cases wanted.  The first gets appended to the middle(s) and to he last. Otherwise, "n".
 ];
-$vals{5}{obs_modify} = 
+$vals{1}{5}{obs_modify} = 
 [   
 [ 
 "/zones/box.geo",
 [ "i"  , "b", [ [ 0, 0, 0 ], [ 0, 0, 3 ] ] ] # IT MODIFIES THE DIMENSION OF THE SAME OBSTRUCTION ABOVE
 ]
 ];
-#$vals{5}{skipop}  = [ [ " ( ( \$to =~ /_1-2/ ) or ( \$to =~ /_2-2/ ) or ( \$to =~ /_3-2/ ) or ( \$to =~ /_4-2/ ) or ( \$to =~ /_5-2/ ) or ( \$to =~ /_6-2/ ) ) " ] ];
+#$vals{1}{5}{skipop}  = [ [ " ( ( \$to =~ /_1-2/ ) or ( \$to =~ /_2-2/ ) or ( \$to =~ /_3-2/ ) or ( \$to =~ /_4-2/ ) or ( \$to =~ /_5-2/ ) or ( \$to =~ /_6-2/ ) ) " ] ];
 # [ 
 # what to modify? "a" for origin, "b" for dimensions, "c" for z_rotation, "d" for y_rotation, "g" for construction, "h" for opacity, "t" for transform	
 # enter value or values corresponding to the above. If origin coordinates of one extreme of the translation. 
@@ -333,30 +336,30 @@ $vals{5}{obs_modify} =
 
 ######################### PARAMETER 6. #############################
 
-$vals{6}{applytype} = [ [ "rotation", "boxform.cfg", "boxform.cfg", "a" ] ] ; #  @applytype(n) = (["type_of_change", "your_test_file", "file_name_to_which_the_former_will_be_copied_to", "zone_letter"]), 
+$vals{1}{6}{applytype} = [ [ "rotate", "boxform.cfg", "boxform.cfg", "a" ] ] ; #  @applytype(n) = (["type_of_change", "your_test_file", "file_name_to_which_the_former_will_be_copied_to", "zone_letter"]), 
 # the following morphing operations are available: "translation", "rotation", "rotationz", "surface_translation", "vertices_shift", 
 # "surface_rotation", "warping", "construction_reassignment", "thickness_change", "obs_modification", "generic_change", "vary_controls", “vary_net”, 
 # "change_groundreflectance", "generic_changeandconstrain"
-$vals{6}{general_variables} = 
+$vals{1}{6}{general_variables} = 
 [
 "n", # $generate(n) eq "n" # (if the models deriving from this runs will not be generating new models) or y (if they will be generating new models).
 "n" #if $sequencer eq "y", or "last" (of a sequence) iteration between non-continuous cases wanted.  The first gets appended to the middle(s) and to he last. Otherwise, "n".
 ];
-$vals{6}{rotate} = 
+$vals{1}{6}{rotate} = 
 [ 
 [ "y", "180", "c", "a" ],
 ];
-#$vals{6}{skipop}  = [ [ " ( ( \$to =~ /_1-2/ ) or ( \$to =~ /_2-2/ ) or ( \$to =~ /_3-2/ ) or ( \$to =~ /_4-2/ ) or ( \$to =~ /_5-2/ ) or ( \$to =~ /_6-2/ ) ) " ] ];
-#$vals{6}{skipop} = [ [ " ( ( $to =~ /_6-5/ ) ) " ] ];
+#$vals{1}{6}{skipop}  = [ [ " ( ( \$to =~ /_1-2/ ) or ( \$to =~ /_2-2/ ) or ( \$to =~ /_3-2/ ) or ( \$to =~ /_4-2/ ) or ( \$to =~ /_5-2/ ) or ( \$to =~ /_6-2/ ) ) " ] ];
+#$vals{1}{6}{skipop} = [ [ " ( ( $to =~ /_6-5/ ) ) " ] ];
 # [ # rotate obstructions? "y" o "n", # swing of rotation (HALF SWING, SWING MEASURED ON ONE SIDE WITH REGARDS TO THE MIDDLE) 
 # update radiation calculation with the "ish" module?  "b" for yes and "c" for no, continue, # vertex around which to rotate ]
 ##### @applytype111 = (["rotation", "file_name", "target_file_name", "zone_letter"]);
-$vals{6}{recalculateish} = [["y"]]; 
+$vals{1}{6}{recalculateish} = [["y"]]; 
 ## recalculate the solar radiation? "y" or "n". This way the "ish" module is launched just at the end of a whole morphing operation, and not at every sub-operations composing it.
-$vals{6}{export_toenergyplus} = [ [ "y", "sim", "retrieve", "milan.epw", [ "FullInteriorAndExterior", "FullInteriorAndExteriorWithReflections" ], 
+$vals{1}{6}{export_toenergyplus} = [ [ "y", "sim", "retrieve", "milan.epw", [ "FullInteriorAndExterior", "FullInteriorAndExteriorWithReflections" ], 
 [ "4;   !- Time Step in Hour", "1;   !- Time Step in Hour" ], [ "1, 1,   !- Begin Month", "2, 1,   !- Begin Month" ], 
 [ "12,31,   !- End Month", " 2, 7,   !- End Month" ] ] ];
-$vals{6}{use_modish} = 
+$vals{1}{6}{use_modish} = 
 [
 [
 [ 1, "/zones/box.shd", 7 ]
@@ -365,16 +368,16 @@ $vals{6}{use_modish} =
 
 ######################### PARAMETER 7. #############################
 
-#$vals{7}{applytype} = [ [ "change_groundreflectance", "boxform.cfg", "boxform.cfg", "a" ] ] ; #  @applytype(n) = (["type_of_change", "your_test_file", "file_name_to_which_the_former_will_be_copied_to", "zone_letter"]), 
+#$vals{1}{7}{applytype} = [ [ "change_groundreflectance", "boxform.cfg", "boxform.cfg", "a" ] ] ; #  @applytype(n) = (["type_of_change", "your_test_file", "file_name_to_which_the_former_will_be_copied_to", "zone_letter"]), 
 ## the following morphing operations are available: "translation", "rotation", "rotationz", "surface_translation", "vertices_shift", 
 ## "surface_rotation", "warping", "construction_reassignment", "thickness_change", "obs_modification", "generic_change", "vary_controls", “vary_net”, 
 ## "change_groundreflectance", "generic_changeandconstrain"
-#$vals{7}{general_variables} = 
+#$vals{1}{7}{general_variables} = 
 #[
 #"y", # $generate(n) eq "n" # (if the models deriving from this runs will not be generating new models) or y (if they will be generating new models).
 #"n" #if $sequencer eq "y", or "last" (of a sequence) iteration between non-continuous cases wanted.  The first gets appended to the middle(s) and to he last. Otherwise, "n".
 #];
-#$vals{7}{change_groundreflectance} =  
+#$vals{1}{7}{change_groundreflectance} =  
 #[ 
 #[ 20, [ 20, 50 ] ] # [ base value, [ low, high ] ]; OR: [ base value, half-range ];
 #];
@@ -382,16 +385,16 @@ $vals{6}{use_modish} =
 
 ######################### PARAMETER 8. #############################
 
-#$vals{8}{applytype} = [ [ "change_climate", "boxform.cfg", "boxform.cfg", "a" ] ] ; #  @applytype(n) = (["type_of_change", "your_test_file", "file_name_to_which_the_former_will_be_copied_to", "zone_letter"]), 
+#$vals{1}{8}{applytype} = [ [ "change_climate", "boxform.cfg", "boxform.cfg", "a" ] ] ; #  @applytype(n) = (["type_of_change", "your_test_file", "file_name_to_which_the_former_will_be_copied_to", "zone_letter"]), 
 ## the following morphing operations are available: "translation", "rotation", "rotationz", "surface_translation", "vertices_shift", 
 ## "surface_rotation", "warping", "construction_reassignment", "thickness_change", "obs_modification", "generic_change", "vary_controls", “vary_net”, 
 ## "change_groundreflectance", "generic_changeandconstrain"
-#$vals{8}{general_variables} = 
+#$vals{1}{8}{general_variables} = 
 #[
 #"n", # $generate(n) eq "n" # (if the models deriving from this runs will not be generating new models) or y (if they will be generating new models).
 #"n" #if $sequencer eq "y", or "last" (of a sequence) iteration between non-continuous cases wanted.  The first gets appended to the middle(s) and to he last. Otherwise, "n".
 #];
-#$vals{8}{change_climate} = 
+#$vals{1}{8}{change_climate} = 
 #[
 #[ "../dbs/milan", "../dbs/cairo", "../dbs/glasgow" ]
 #]; # THE FULL PATH OF EACH FILE MUST BE SPECIFIED AND EACH FILE MUST ALREADY BE IN THE ESP-r FORMAT
@@ -489,7 +492,7 @@ $stepsvar111 = 3 ;
 #  Number of steps for this variable.  This should better be an odd number, 
 # since thiat way one number will be the central one, which is, the one already supplied in the starting model;
 
-$vals{111}{applytype} = 
+$vals{1}{111}{applytype} = 
 [ 
 [ "surface_translation", "zone.cfg", "zone.cfg", "a" ],
 ]; 
@@ -506,18 +509,18 @@ $vals{111}{applytype} =
 # "Target file" here means: "file name to which the test file has to be copied to"
 # [ type_of_change, test_file, target_file. If it is the same as the test file, no copying takes place, zone letter in the model ]
 
-$vals{111}{copy_config} = 
+$vals{1}{111}{copy_config} = 
 [
 [ "file_old", "file_new" ],
 ];
 # file to be substituted,  # file substituting
 
-$vals{111}{general_variables} = 
+$vals{1}{111}{general_variables} = 
 [ "y", "n" ];
 # 1) generate other models by branching? "y" or "n". 2) attach the morphing operation of the next morphing phase to the present one without generating new cases? 
 # If "yes", you'll see the symbol "" attached to file names in place of "_" for morphed models.
 
-$vals{111}{translate} =  
+$vals{1}{111}{translate} =  
 [ 
 [ "n", ["9", "0", "0"], "c", ],
 ];
@@ -530,12 +533,12 @@ $vals{111}{translate} =
 # update radiation calculation with the "ish" module?  "a" for yes and "c" for no (= continue).
 #### @applytype111 = ( ["translation", "file_name", "target_file_name", "zone_letter"]); 
 
-$vals{111}{change_groundreflectance} =  
+$vals{1}{111}{change_groundreflectance} =  
 [ 
 [ 80, [ 50, 80 ] ] # [ base value, [ low, high ] ]; OR: [ base value, half-range ];
 ];
 
-$vals{111}{translate_surface} =  
+$vals{1}{111}{translate_surface} =  
 [ 
 [ "a", [ "b", "d" ], [  1, 1  ] , "c", ],
 ];
@@ -549,7 +552,7 @@ $vals{111}{translate_surface} =
 # update radiation? "b" for yes or "c" for no.
 #### @applytype111 = ( ["surface_translation", "file_name", "target_file_name", "zone_letter"]); 
 
-$vals{111}{shift_vertices} = 
+$vals{1}{111}{shift_vertices} = 
 [ 
 [ "j", [ "i" , "q" , "j", "r" , "m" , "0\ns", "n", "0\nt" , "0\nv", "c", "0\nu", "d", "0\nz", "f", "0\ny", "e" ], [ 0.8, 0.8, 0.8, 0.8, 0.8, 0.8, 0.8, 0.8 ], "c", ],
 ];
@@ -561,7 +564,7 @@ $vals{111}{shift_vertices} =
 # ]
 #### @applytype111 = ( ["vertices_shift", "file_name", "target_file_name", "zone_letter"]);
 
-$vals{111}{rotate_surface} = 
+$vals{1}{111}{rotate_surface} = 
 [ 
 [   [ "b", "d" ], [ 10, 12 ], [ 30, 30 ] , [ "y", "y" ]   ]
 ];
@@ -572,7 +575,7 @@ $vals{111}{rotate_surface} =
 # [ apply to others? "y" or "n" ]
 ##### @applytype111 = [ ["surface_rotation", "file_name", "target_file_name", "zone_letter"]);
 
-$vals{111}{translate_vertices} = 
+$vals{1}{111}{translate_vertices} = 
 [ 
 [ 
 [ "a", "i", "0\ny", "j",  "b", "f", "k", "l", "e",  "d", "0\nr", "0\na", "0\nq", "c", "g", "0\nt", "0\ns", "h" ],  
@@ -586,7 +589,7 @@ $vals{111}{translate_vertices} =
 # source file, # long menus?
 
 
-$vals{111}{rotate} = 
+$vals{1}{111}{rotate} = 
 [ 
 [ "n", "90", "c", "a" ],
 ];
@@ -596,7 +599,7 @@ $vals{111}{rotate} =
 
 
 
-$vals{111}{construction_reassignment} = 
+$vals{1}{111}{construction_reassignment} = 
 [ 
 [
 [ "a", "b", "c", "d", "e", "f" , "k", "l", "m", "n", "o", "p", "q", "r"  ], 
@@ -614,7 +617,7 @@ $vals{111}{construction_reassignment} =
  ##### @applytype111 = (["construction_reassignment", "file_name", "target_file_name", "zone_letter"]);
  
  
-$vals{111}{change_thickness} = 
+$vals{1}{111}{change_thickness} = 
 [ 
 [
 [ a, b, c ], 
@@ -630,7 +633,7 @@ $vals{111}{change_thickness} =
 ##### @applytype111 = ( ["thickness_change", "file_name", "target_file_name", "zone_letter"]); 
 
 
-$vals{111}{obs_modify} = 
+$vals{1}{111}{obs_modify} = 
 [   
 [  [ "i","j", "k", "l" ] , "c", [ 45 ], [180]  ],
 ];
@@ -644,7 +647,7 @@ $vals{111}{obs_modify} =
 ### @applytype111 = (["obs_modification",trans "cell.geo", "cell.geo", "a"], ["obs_modification", "cell.geo", "cell.geo", "a"]);
 
 
-$vals{111}{keep_obstructions} = ##### BRING SOME OBSTRUCTIONS BACK IN THE ORIGINAL POSITION AFTER ALL OF THEM HAVE BEEN MOVED.
+$vals{1}{111}{keep_obstructions} = ##### BRING SOME OBSTRUCTIONS BACK IN THE ORIGINAL POSITION AFTER ALL OF THEM HAVE BEEN MOVED.
 [
 { 
 what => "read", tempname => "../tmp/rem1.tmp", obsnumbers => [ 1, 2 ]
@@ -653,7 +656,7 @@ what => "read", tempname => "../tmp/rem1.tmp", obsnumbers => [ 1, 2 ]
 # { what => "read" or "write", tempname => name of the temporary file, obsnumbers => obstruction numbers }
 
  
-$vals{111}{warp} = 
+$vals{1}{111}{warp} = 
 [ 
 [   
 [ "b", "d" ],  #  surfaces to warp
@@ -669,20 +672,20 @@ $vals{111}{warp} =
 ];
 
 
-$vals{111}{rotatez} = 
+$vals{1}{111}{rotatez} = 
 [ [ 0.7, 0.7, 0.02 ], "x", 90, 0, 0, 0 ]; 
 # [ # x, y (or x) and z of the point that is the center of the axis rotation ],
 # # plan of rotation: x or y, # rotation swing of plane xy, # rotation already had by the zone with respect to the x axis, # rotation on plane yz - TO DO, # swing for the rotation on plane xy - TO DO
 ###  @applytype(n) = [["type_of_change", "your_test_file", "file_name_to_which_the_former_will_be_copied_to", "zone_letter"]). # THIS ROUTINE KEEPS THE OBSTRUCTIONS STILL AND ROTATE THE ZONE(S) ON THE ALTITUDE ANGLE.  IT DOES NOT PASS THROUGH ESP-R.  IT JUST MANAGES THE .GEO CONFIGURATION FILE.
 
-$vals{111}{generic_change} = ""; ##### # @applytype111 = [["generic_change", "file_name", "target_file_name", "zone_letter"]); TO BE REVRITTEN
+$vals{1}{111}{generic_change} = ""; ##### # @applytype111 = [["generic_change", "file_name", "target_file_name", "zone_letter"]); TO BE REVRITTEN
 
-$vals{111}{change_climate} = 
+$vals{1}{111}{change_climate} = 
 [
 [ "../dbs/asyut", "../dbs/rome", "../dbs/newdelhi" ]
 ]; # THE FULL PATH OF EACH FILE MUST BE SPECIFIED AND EACH FILE MUST ALREADY BE IN THE ESP-r FORMAT
 
-$vals{111}{reshape_windows} = [
+$vals{1}{111}{reshape_windows} = [
 [
 [ 
 [ "/zones/zone.geo" ], # source file
@@ -697,7 +700,7 @@ $vals{111}{reshape_windows} = [
 ]; 
 
 
-$vals{111}{apply_constraints} = ##### APPLY PROPAGATION OF CONSTRAINTS TO THE MODEL AFTER A CERTAIN CHANGE; GENERAL. YOU HAVE TO WRITE A CONFIGURATION FILES TO DO IT. (SEE EXAMPLE MODELS.)
+$vals{1}{111}{apply_constraints} = ##### APPLY PROPAGATION OF CONSTRAINTS TO THE MODEL AFTER A CERTAIN CHANGE; GENERAL. YOU HAVE TO WRITE A CONFIGURATION FILES TO DO IT. (SEE EXAMPLE MODELS.)
 [
 [ 
 ["/zones/zone.geo"], # source file
@@ -711,7 +714,7 @@ $vals{111}{apply_constraints} = ##### APPLY PROPAGATION OF CONSTRAINTS TO THE MO
 ]; 
 
 
-$vals{111}{constrain_geometry} = # This is similar to "apply_constraints", but more general, because the propagation here criteria has to be specified in the configuration file. 
+$vals{1}{111}{constrain_geometry} = # This is similar to "apply_constraints", but more general, because the propagation here criteria has to be specified in the configuration file. 
 [  
 [
 "/zones/zone.geo", # source file
@@ -737,7 +740,7 @@ $vals{111}{constrain_geometry} = # This is similar to "apply_constraints", but m
 ## If the alphabetical order is not accepted as an order to propagate constraints, a new order can be specificed
 ## WITH THE FOLLOWING VARIABLE: @vertexletters
 
-$vals{111}{constrain_obstructions} = # To apply constraints to and from obstructions.
+$vals{1}{111}{constrain_obstructions} = # To apply constraints to and from obstructions.
 [ 
 [
 "a", # zone letter
@@ -770,7 +773,7 @@ $vals{111}{constrain_obstructions} = # To apply constraints to and from obstruct
 ## WITH THE FOLLOWING VARIABLE:  @obs_letters 
 
 
-$vals{111}{vary_controls} = 
+$vals{1}{111}{vary_controls} = 
 [ 
 [
 "/ctl/cell.ctl", # source file
@@ -810,7 +813,7 @@ $vals{111}{vary_controls} =
 ];
 
 
-$vals{111}{constrain_controls} = # to apply contraints to and from controls.
+$vals{1}{111}{constrain_controls} = # to apply contraints to and from controls.
 [
 [
 "/ctl/cell.ctl", # source file
@@ -846,7 +849,7 @@ $vals{111}{constrain_controls} = # to apply contraints to and from controls.
 ## If the alphabetical order is not accepted as an order to propagate constraints, a new order can be specificed
 ## WITH THE FOLLOWING VARIABLES: @letters AND @period_letters
 
-$vals{111}{vary_net} = 
+$vals{1}{111}{vary_net} = 
 [ 
 [
 "/nets/cell.afn", # source file
@@ -899,7 +902,7 @@ $vals{111}{vary_net} =
 ## WITH THE FOLLOWING VARIABLES:
 ## @node_letters AND @component_letters 
 
-$vals{111}{constrain_net} = 
+$vals{1}{111}{constrain_net} = 
 [
 [
 "/nets/cell.afn", # source file
@@ -950,7 +953,7 @@ $vals{111}{constrain_net} =
 ## @node_letters AND @component_letters (FOR NETS), @letters AND @period_letters (FOR CONTROLS)
 
 
-$vals{111}{propagate_constraints} = [ 
+$vals{1}{111}{propagate_constraints} = [ 
 [
 [ "read_geo", # what to do
 "/zones/zone.geo", # source file
@@ -1074,10 +1077,10 @@ $vals{111}{propagate_constraints} = [
 ## THE VARIABLE AT THE CURRENT SEARCH STEP CAN BE NAMED WITHOUT THE NUMBER. EXAMPLE: $recalculateish, $translate, ETC.
 
 
-$vals{111}{recalculateish} = [ [ "n" ] ];
+$vals{1}{111}{recalculateish} = [ [ "n" ] ];
 ## recalculate the solar radiation? "y" or "n". This way the "ish" module is launched just at the end of a whole morphing operation, and not at every sub-operations composing it.
 
-$vals{111}{use_modish} = 
+$vals{1}{111}{use_modish} = 
 [
 [
 [ 1, "./relative_path_to_ishfile/ishfile.shd", 7 ]
@@ -1097,7 +1100,7 @@ $vals{111}{use_modish} =
 ## SO: $vals{1}{export_toenergyplus} = [ [ "y", [ "word1_to_substitute", "substituting_word1]" ], [ "word2_to_substitute", "substituting_word2]" ], ... ] ];
 
 
-$vals{111}{generic_changeandconstrain} = 
+$vals{1}{111}{generic_changeandconstrain} = 
 [
 [
 [ "/relative_constrainfile1_path", "/relative_constrainfile2_path" ], #FILE IN WHICH RULES FOR PROPAGATION OF CONSTRAINTS ARE WRITTEN. THEY ARE READ_AND_PROPAGATED ONE BY ONE, SEQUENTIALLY. # GIVE SEMI-LOCAL PATH WITHOUT THE DOTS (EXAMPLE: "/cfg/file".
@@ -1113,7 +1116,7 @@ $vals{111}{generic_changeandconstrain} =
 ];
 
 
-$vals{111}{recalculatenet} = # here the net is re-set using new pressure coefficients.
+$vals{1}{111}{recalculatenet} = # here the net is re-set using new pressure coefficients.
 [ 
 "../nets/cell.afn", # path to the file, starting from a model's root directory. Example: "./nets/cell.afn".
 [
@@ -1124,7 +1127,7 @@ $vals{111}{recalculatenet} = # here the net is re-set using new pressure coeffic
 ]; 
 
 
-$vals{111}{daylightcalc} = [   ##### THIS VARIABLE GOVERNS A FUNCTION WHICH LAUNCHED DAYLIGHT FACTOR CALCULATION THROUGH RADIANCE. PLEASE NOTICE THAT EVEN THIS FUNCTION PRESENTLY WORKS ONLY FOR A SINGLE ZONE. ALSO NOTICE THAT THIS OPERATION HAS NOT YET BEEN WRITTEN TO BE USED IN SEQUENCE WITH OTHER OPERATIONS IN THE SAME MORPHING PHASE. SO USE IT IN THE FIRST SEQUENCE OF THIS PHASE, AND KEEP JUST ONE SEQUENCE IN THIS PHASE.
+$vals{1}{111}{daylightcalc} = [   ##### THIS VARIABLE GOVERNS A FUNCTION WHICH LAUNCHED DAYLIGHT FACTOR CALCULATION THROUGH RADIANCE. PLEASE NOTICE THAT EVEN THIS FUNCTION PRESENTLY WORKS ONLY FOR A SINGLE ZONE. ALSO NOTICE THAT THIS OPERATION HAS NOT YET BEEN WRITTEN TO BE USED IN SEQUENCE WITH OTHER OPERATIONS IN THE SAME MORPHING PHASE. SO USE IT IN THE FIRST SEQUENCE OF THIS PHASE, AND KEEP JUST ONE SEQUENCE IN THIS PHASE.
 "a", # zone letter
 "f", # surface with respect to which daylight factors have to be calculated
 "a", # "a" for Inside, "b" for Outside: what daylight factor have to be calculated with respect to
@@ -1135,7 +1138,7 @@ $vals{111}{daylightcalc} = [   ##### THIS VARIABLE GOVERNS A FUNCTION WHICH LAUN
 "cell_Day_fa.df" # name of daylight factor file
 ]; #
 
-$vals{111}{skipop} = 
+$vals{1}{111}{skipop} = 
 [
 [ 
 " ( ( \$translate->[\$counterzone][2][0] > 2 ) or ( \$translate_>[\$counterzone][2][0] < 8 ) ) "
@@ -1165,7 +1168,7 @@ $vals{111}{use_modish} =
 ]; 
 
 
-$vals{112}{translate_surface} =  
+$vals{1}{112}{translate_surface} =  
 [ 
 [ "b", [ "b", "d" ], [  1, 1  ] , "c", [ [ -4, -5, -6], [ 4, 5, 6] ] ],
 ];
@@ -1175,12 +1178,12 @@ $vals{112}{translate_surface} =
 # update radiation? "b" for yes or "c" for no.
 #### @applytype111 = ( ["surface_translation", "file_name", "target_file_name", "zone_letter"]); 
 
-$vals{112}{translate} =  
+$vals{1}{112}{translate} =  
 [ 
 [ "n", [ ["-9", "0", "0"], ["9", "0", "0"] ], "c", ],
 ];
 
-$vals{112}{rotate_surface} = 
+$vals{1}{112}{rotate_surface} = 
 [ 
 [   [ "b", "d" ], [ 10, 12 ], [ [ -30, 30 ], [ -30, 30]  ] , [ "y", "y" ]   ]
 ];
@@ -1191,12 +1194,12 @@ $vals{112}{rotate_surface} =
 # [ apply to others? "y" or "n" ]
 ##### @applytype111 = [ ["surface_rotation", "file_name", "target_file_name", "zone_letter"]);
 
-$vals{112}{rotate} = 
+$vals{1}{112}{rotate} = 
 [ 
 [ "y", [ -180, 180 ], "c", "a" ],
 ];
 
-$vals{112}{translate_vertices} = 
+$vals{1}{112}{translate_vertices} = 
 [ 
 [ 
 [ "a", "b", ],  
@@ -1209,7 +1212,7 @@ $vals{112}{translate_vertices} =
 # [ [ x y z movs ] ],  in case of surface x y z translation
 # source file, # long menus?
 
-$vals{112}{shift_vertices} = 
+$vals{1}{112}{shift_vertices} = 
 [ 
 [ "j", [ "i" , "l" , "m" ], [ [ -0.8, 0.8 ], [ -0.4, 0.4 ],[ -0.3, 0.3 ] ], "c", ],
 ];
